import eigenpy
import typing

__all__ = [
    "AngleAxis",
    "ColPivHouseholderQR",
    "CompleteOrthogonalDecomposition",
    "ComputationInfo",
    "DecompositionOptions",
    "EigenSolver",
    "Exception",
    "FullPivHouseholderQR",
    "HouseholderQR",
    "LDLT",
    "LLT",
    "MINRES",
    "PermutationMatrix",
    "Quaternion",
    "SelfAdjointEigenSolver",
    "SimdInstructionSetsInUse",
    "SimplicialLDLT",
    "SimplicialLLT",
    "StdVec_MatrixXd",
    "StdVec_MatrixXi",
    "StdVec_VectorXd",
    "StdVec_VectorXi",
    "checkVersionAtLeast",
    "eigenpy_pywrap",
    "fromEulerAngles",
    "is_approx",
    "seed",
    "sharedMemory",
    "solvers",
    "toEulerAngles"
]

class AngleAxis(Boost.Python.instance):
    """
    AngleAxis representation of a rotation.
    """
    @staticmethod
    def __eq__(arg1: AngleAxis, arg2: AngleAxis) -> bool: 
        """
        __eq__( (AngleAxis)arg1, (AngleAxis)arg2) -> bool :

            C++ signature :
                bool __eq__(Eigen::AngleAxis<double>,Eigen::AngleAxis<double>)
        """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,double,Eigen::Matrix<double, 3, 1, 0, 3, 1>)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, 3, 3, 0, 3, 3>)

            C++ signature :
                void __init__(_object*,Eigen::Quaternion<double, 0>)

            C++ signature :
                void __init__(_object*,Eigen::AngleAxis<double>)
        """
    @typing.overload
    def __init__(self, R: numpy.ndarray) -> None: ...
    @typing.overload
    def __init__(self, angle: float, axis: numpy.ndarray) -> None: ...
    @typing.overload
    def __init__(self, copy: AngleAxis) -> None: ...
    @typing.overload
    def __init__(self, quaternion: Quaternion) -> None: ...
    @staticmethod
    @typing.overload
    def __mul__(arg1: AngleAxis, arg2: AngleAxis) -> object: 
        """
        __mul__( (AngleAxis)arg1, (numpy.ndarray)arg2) -> object :

            C++ signature :
                _object* __mul__(Eigen::AngleAxis<double> {lvalue},Eigen::Matrix<double, 3, 1, 0, 3, 1>)

            C++ signature :
                _object* __mul__(Eigen::AngleAxis<double> {lvalue},Eigen::Quaternion<double, 0>)

            C++ signature :
                _object* __mul__(Eigen::AngleAxis<double> {lvalue},Eigen::AngleAxis<double>)
        """
    @staticmethod
    @typing.overload
    def __mul__(arg1: AngleAxis, arg2: Quaternion) -> object: ...
    @staticmethod
    @typing.overload
    def __mul__(arg1: AngleAxis, arg2: numpy.ndarray) -> object: ...
    @staticmethod
    def __ne__(arg1: AngleAxis, arg2: AngleAxis) -> bool: 
        """
        __ne__( (AngleAxis)arg1, (AngleAxis)arg2) -> bool :

            C++ signature :
                bool __ne__(Eigen::AngleAxis<double>,Eigen::AngleAxis<double>)
        """
    @staticmethod
    def __repr__(arg1: AngleAxis) -> str: 
        """
        __repr__( (AngleAxis)arg1) -> str :

            C++ signature :
                std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > __repr__(Eigen::AngleAxis<double>)
        """
    @staticmethod
    def __str__(arg1: AngleAxis) -> str: 
        """
        __str__( (AngleAxis)arg1) -> str :

            C++ signature :
                std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > __str__(Eigen::AngleAxis<double>)
        """
    def fromRotationMatrix(self, rotation_matrix: numpy.ndarray) -> AngleAxis: 
        """
        fromRotationMatrix( (AngleAxis)self, (numpy.ndarray)rotation matrix) -> AngleAxis :
            Sets *this from a 3x3 rotation matrix

            C++ signature :
                Eigen::AngleAxis<double> {lvalue} fromRotationMatrix(Eigen::AngleAxis<double> {lvalue},Eigen::MatrixBase<Eigen::Matrix<double, 3, 3, 0, 3, 3> >)
        """
    def id(self) -> int: 
        """
        id( (AngleAxis)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::AngleAxis<double>)
        """
    def inverse(self) -> AngleAxis: 
        """
        inverse( (AngleAxis)self) -> AngleAxis :
            Return the inverse rotation.

            C++ signature :
                Eigen::AngleAxis<double> inverse(Eigen::AngleAxis<double> {lvalue})
        """
    def isApprox(self, other_: AngleAxis, prec: float) -> bool: 
        """
        isApprox( (AngleAxis)self, (AngleAxis)other [, (float)prec]) -> bool :
            Returns true if *this is approximately equal to other, within the precision determined by prec.

            C++ signature :
                bool isApprox(Eigen::AngleAxis<double>,Eigen::AngleAxis<double> [,double])
        """
    def matrix(self) -> numpy.ndarray: 
        """
        matrix( (AngleAxis)self) -> numpy.ndarray :
            Returns an equivalent rotation matrix.

            C++ signature :
                Eigen::Matrix<double, 3, 3, 0, 3, 3> matrix(Eigen::AngleAxis<double> {lvalue})
        """
    @staticmethod
    def toRotationMatrix(arg1: AngleAxis) -> numpy.ndarray: 
        """
        toRotationMatrix( (AngleAxis)arg1) -> numpy.ndarray :
            Constructs and returns an equivalent rotation matrix.

            C++ signature :
                Eigen::Matrix<double, 3, 3, 0, 3, 3> toRotationMatrix(Eigen::AngleAxis<double> {lvalue})
        """
    @property
    def angle(self) -> None:
        """
        The rotation angle.

        :type: None
        """
    @property
    def axis(self) -> None:
        """
        The rotation axis.

        :type: None
        """
    pass

class ColPivHouseholderQR(Boost.Python.instance):
    """
    This class performs a rank-revealing QR decomposition of a matrix A into matrices P, Q and R such that:
    AP=QR
    by using Householder transformations. Here, P is a permutation matrix, Q a unitary matrix and R an upper triangular matrix.

    This decomposition performs column pivoting in order to be rank-revealing and improve numerical stability. It is slower than HouseholderQR, and faster than FullPivHouseholderQR.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor.
            The default constructor is useful in cases in which the user intends to perform decompositions via HouseholderQR.compute(matrix)

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,long,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def __init__(self, matrix: numpy.ndarray) -> None: ...
    @typing.overload
    def __init__(self, rows: int, cols: int) -> None: ...
    def absDeterminant(self) -> float: 
        """
        absDeterminant( (ColPivHouseholderQR)self) -> float :
            Returns the absolute value of the determinant of the matrix of which *this is the QR decomposition.
            It has only linear complexity (that is, O(n) where n is the dimension of the square matrix) as the QR decomposition has already been computed.
            Note: This is only for square matrices.

            C++ signature :
                double absDeterminant(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def compute(self, matrix: numpy.ndarray) -> ColPivHouseholderQR: 
        """
        compute( (ColPivHouseholderQR)self, (numpy.ndarray)matrix) -> ColPivHouseholderQR :
            Computes the QR factorization of given matrix.

            C++ signature :
                Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} compute(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def dimensionOfKernel(self) -> int: 
        """
        dimensionOfKernel( (ColPivHouseholderQR)self) -> int :
            Returns the dimension of the kernel of the matrix of which *this is the QR decomposition.

            C++ signature :
                long dimensionOfKernel(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def id(self) -> int: 
        """
        id( (ColPivHouseholderQR)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def info(self) -> ComputationInfo: 
        """
        info( (ColPivHouseholderQR)self) -> ComputationInfo :
            Reports whether the QR factorization was successful.
            Note: This function always returns Success. It is provided for compatibility with other factorization routines.

            C++ signature :
                Eigen::ComputationInfo info(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def inverse(self) -> numpy.ndarray: 
        """
        inverse( (ColPivHouseholderQR)self) -> numpy.ndarray :
            Returns the inverse of the matrix associated with the QR decomposition..

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> inverse(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def isInjective(self) -> bool: 
        """
        isInjective( (ColPivHouseholderQR)self) -> bool :
            Returns true if the matrix associated with this QR decomposition represents an injective linear map, i.e. has trivial kernel; false otherwise.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isInjective(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def isInvertible(self) -> bool: 
        """
        isInvertible( (ColPivHouseholderQR)self) -> bool :
            Returns true if the matrix associated with the QR decomposition is invertible.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isInvertible(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def isSurjective(self) -> bool: 
        """
        isSurjective( (ColPivHouseholderQR)self) -> bool :
            Returns true if the matrix associated with this QR decomposition represents a surjective linear map; false otherwise.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isSurjective(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def logAbsDeterminant(self) -> float: 
        """
        logAbsDeterminant( (ColPivHouseholderQR)self) -> float :
            Returns the natural log of the absolute value of the determinant of the matrix of which *this is the QR decomposition.
            It has only linear complexity (that is, O(n) where n is the dimension of the square matrix) as the QR decomposition has already been computed.
            Note: This is only for square matrices. This method is useful to work around the risk of overflow/underflow that's inherent to determinant computation.

            C++ signature :
                double logAbsDeterminant(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def matrixQR(self) -> numpy.ndarray: 
        """
        matrixQR( (ColPivHouseholderQR)self) -> numpy.ndarray :
            Returns the matrix where the Householder QR decomposition is stored in a LAPACK-compatible way.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixQR(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def matrixR(self) -> numpy.ndarray: 
        """
        matrixR( (ColPivHouseholderQR)self) -> numpy.ndarray :
            Returns the matrix where the result Householder QR is stored.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixR(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def maxPivot(self) -> float: 
        """
        maxPivot( (ColPivHouseholderQR)self) -> float :
            Returns the absolute value of the biggest pivot, i.e. the biggest diagonal coefficient of U.

            C++ signature :
                double maxPivot(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def nonzeroPivots(self) -> int: 
        """
        nonzeroPivots( (ColPivHouseholderQR)self) -> int :
            Returns the number of nonzero pivots in the QR decomposition. Here nonzero is meant in the exact sense, not in a fuzzy sense. So that notion isn't really intrinsically interesting, but it is still useful when implementing algorithms.

            C++ signature :
                long nonzeroPivots(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def rank(self) -> int: 
        """
        rank( (ColPivHouseholderQR)self) -> int :
            Returns the rank of the matrix associated with the QR decomposition.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                long rank(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def setThreshold(self, threshold: float) -> ColPivHouseholderQR: 
        """
        setThreshold( (ColPivHouseholderQR)self, (float)threshold) -> ColPivHouseholderQR :
            Allows to prescribe a threshold to be used by certain methods, such as rank(), who need to determine when pivots are to be considered nonzero. This is not used for the QR decomposition itself.
            
            When it needs to get the threshold value, Eigen calls threshold(). By default, this uses a formula to automatically determine a reasonable threshold. Once you have called the present method setThreshold(const RealScalar&), your value is used instead.
            
            Note: A pivot will be considered nonzero if its absolute value is strictly greater than |pivot| ⩽ threshold×|maxpivot| where maxpivot is the biggest pivot.

            C++ signature :
                Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} setThreshold(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},double)
        """
    def solve(self, B: numpy.ndarray) -> numpy.ndarray: 
        """
        solve( (ColPivHouseholderQR)self, (numpy.ndarray)B) -> numpy.ndarray :
            Returns the solution X of A X = B using the current decomposition of A where B is a right hand side matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> >,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    def threshold(self) -> float: 
        """
        threshold( (ColPivHouseholderQR)self) -> float :
            Returns the threshold that will be used by certain methods such as rank().

            C++ signature :
                double threshold(Eigen::ColPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    pass

class CompleteOrthogonalDecomposition(Boost.Python.instance):
    """
    This class performs a rank-revealing complete orthogonal decomposition of a matrix A into matrices P, Q, T, and Z such that:
    AP=Q[T000]Zby using Householder transformations. Here, P is a permutation matrix, Q and Z are unitary matrices and T an upper triangular matrix of size rank-by-rank. A may be rank deficient.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor.
            The default constructor is useful in cases in which the user intends to perform decompositions via CompleteOrthogonalDecomposition.compute(matrix)

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,long,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def __init__(self, matrix: numpy.ndarray) -> None: ...
    @typing.overload
    def __init__(self, rows: int, cols: int) -> None: ...
    def absDeterminant(self) -> float: 
        """
        absDeterminant( (CompleteOrthogonalDecomposition)self) -> float :
            Returns the absolute value of the determinant of the matrix associated with the complete orthogonal decomposition.
            It has only linear complexity (that is, O(n) where n is the dimension of the square matrix) as the complete orthogonal decomposition has already been computed.
            Note: This is only for square matrices.

            C++ signature :
                double absDeterminant(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def compute(self, matrix: numpy.ndarray) -> CompleteOrthogonalDecomposition: 
        """
        compute( (CompleteOrthogonalDecomposition)self, (numpy.ndarray)matrix) -> CompleteOrthogonalDecomposition :
            Computes the complete orthogonal factorization of given matrix.

            C++ signature :
                Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} compute(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def dimensionOfKernel(self) -> int: 
        """
        dimensionOfKernel( (CompleteOrthogonalDecomposition)self) -> int :
            Returns the dimension of the kernel of the matrix of which *this is the complete orthogonal decomposition.

            C++ signature :
                long dimensionOfKernel(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def id(self) -> int: 
        """
        id( (CompleteOrthogonalDecomposition)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def info(self) -> ComputationInfo: 
        """
        info( (CompleteOrthogonalDecomposition)self) -> ComputationInfo :
            Reports whether the complete orthogonal factorization was successful.
            Note: This function always returns Success. It is provided for compatibility with other factorization routines.

            C++ signature :
                Eigen::ComputationInfo info(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def isInjective(self) -> bool: 
        """
        isInjective( (CompleteOrthogonalDecomposition)self) -> bool :
            Returns true if the matrix associated with this complete orthogonal decomposition represents an injective linear map, i.e. has trivial kernel; false otherwise.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isInjective(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def isInvertible(self) -> bool: 
        """
        isInvertible( (CompleteOrthogonalDecomposition)self) -> bool :
            Returns true if the matrix associated with the complete orthogonal decomposition is invertible.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isInvertible(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def isSurjective(self) -> bool: 
        """
        isSurjective( (CompleteOrthogonalDecomposition)self) -> bool :
            Returns true if the matrix associated with this complete orthogonal decomposition represents a surjective linear map; false otherwise.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isSurjective(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def logAbsDeterminant(self) -> float: 
        """
        logAbsDeterminant( (CompleteOrthogonalDecomposition)self) -> float :
            Returns the natural log of the absolute value of the determinant of the matrix of which *this is the complete orthogonal decomposition.
            It has only linear complexity (that is, O(n) where n is the dimension of the square matrix) as the complete orthogonal decomposition has already been computed.
            Note: This is only for square matrices. This method is useful to work around the risk of overflow/underflow that's inherent to determinant computation.

            C++ signature :
                double logAbsDeterminant(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def matrixQTZ(self) -> numpy.ndarray: 
        """
        matrixQTZ( (CompleteOrthogonalDecomposition)self) -> numpy.ndarray :
            Returns the matrix where the complete orthogonal decomposition is stored.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixQTZ(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def matrixT(self) -> numpy.ndarray: 
        """
        matrixT( (CompleteOrthogonalDecomposition)self) -> numpy.ndarray :
            Returns the matrix where the complete orthogonal decomposition is stored.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixT(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def matrixZ(self) -> numpy.ndarray: 
        """
        matrixZ( (CompleteOrthogonalDecomposition)self) -> numpy.ndarray :
            Returns the matrix Z.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixZ(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def maxPivot(self) -> float: 
        """
        maxPivot( (CompleteOrthogonalDecomposition)self) -> float :
            Returns the absolute value of the biggest pivot, i.e. the biggest diagonal coefficient of U.

            C++ signature :
                double maxPivot(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def nonzeroPivots(self) -> int: 
        """
        nonzeroPivots( (CompleteOrthogonalDecomposition)self) -> int :
            Returns the number of nonzero pivots in the complete orthogonal decomposition. Here nonzero is meant in the exact sense, not in a fuzzy sense. So that notion isn't really intrinsically interesting, but it is still useful when implementing algorithms.

            C++ signature :
                long nonzeroPivots(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def pseudoInverse(self) -> numpy.ndarray: 
        """
        pseudoInverse( (CompleteOrthogonalDecomposition)self) -> numpy.ndarray :
            Returns the pseudo-inverse of the matrix associated with the complete orthogonal decomposition.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> pseudoInverse(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def rank(self) -> int: 
        """
        rank( (CompleteOrthogonalDecomposition)self) -> int :
            Returns the rank of the matrix associated with the complete orthogonal decomposition.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                long rank(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def setThreshold(self, threshold: float) -> CompleteOrthogonalDecomposition: 
        """
        setThreshold( (CompleteOrthogonalDecomposition)self, (float)threshold) -> CompleteOrthogonalDecomposition :
            Allows to prescribe a threshold to be used by certain methods, such as rank(), who need to determine when pivots are to be considered nonzero. This is not used for the complete orthogonal decomposition itself.
            
            When it needs to get the threshold value, Eigen calls threshold(). By default, this uses a formula to automatically determine a reasonable threshold. Once you have called the present method setThreshold(const RealScalar&), your value is used instead.
            
            Note: A pivot will be considered nonzero if its absolute value is strictly greater than |pivot| ⩽ threshold×|maxpivot| where maxpivot is the biggest pivot.

            C++ signature :
                Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} setThreshold(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},double)
        """
    def solve(self, B: numpy.ndarray) -> numpy.ndarray: 
        """
        solve( (CompleteOrthogonalDecomposition)self, (numpy.ndarray)B) -> numpy.ndarray :
            Returns the solution X of A X = B using the current decomposition of A where B is a right hand side matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> >,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    def threshold(self) -> float: 
        """
        threshold( (CompleteOrthogonalDecomposition)self) -> float :
            Returns the threshold that will be used by certain methods such as rank().

            C++ signature :
                double threshold(Eigen::CompleteOrthogonalDecomposition<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    pass

class EigenSolver(Boost.Python.instance):
    @staticmethod
    @typing.overload
    def __init__(arg1: object) -> None: 
        """
        __init__( (object)arg1) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1> [,bool])
        """
    @staticmethod
    @typing.overload
    def __init__(arg1: object, matrix_: numpy.ndarray, compute_eigen_vectors: bool) -> None: ...
    @staticmethod
    @typing.overload
    def __init__(arg1: object, size: int) -> None: ...
    @typing.overload
    def compute(self, matrix: numpy.ndarray) -> EigenSolver: 
        """
        compute( (EigenSolver)self, (numpy.ndarray)matrix) -> EigenSolver :
            Computes the eigendecomposition of given matrix.

            C++ signature :
                Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} compute(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)

            C++ signature :
                Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} compute(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >,bool)
        """
    @typing.overload
    def compute(self, matrix: numpy.ndarray, compute_eigen_vectors: bool) -> EigenSolver: ...
    def eigenvalues(self) -> object: 
        """
        eigenvalues( (EigenSolver)self) -> object :
            Returns the eigenvalues of given matrix.

            C++ signature :
                Eigen::Matrix<std::complex<double>, -1, 1, 0, -1, 1> eigenvalues(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def eigenvectors(self) -> numpy.ndarray: 
        """
        eigenvectors( (EigenSolver)self) -> numpy.ndarray :
            Returns the eigenvectors of given matrix.

            C++ signature :
                Eigen::Matrix<std::complex<double>, -1, -1, 0, -1, -1> eigenvectors(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def getMaxIterations(self) -> int: 
        """
        getMaxIterations( (EigenSolver)self) -> int :
            Returns the maximum number of iterations.

            C++ signature :
                long getMaxIterations(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def id(self) -> int: 
        """
        id( (EigenSolver)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def info(self) -> ComputationInfo: 
        """
        info( (EigenSolver)self) -> ComputationInfo :
            NumericalIssue if the input contains INF or NaN values or overflow occured. Returns Success otherwise.

            C++ signature :
                Eigen::ComputationInfo info(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def pseudoEigenvalueMatrix(self) -> numpy.ndarray: 
        """
        pseudoEigenvalueMatrix( (EigenSolver)self) -> numpy.ndarray :
            Returns the block-diagonal matrix in the pseudo-eigendecomposition.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> pseudoEigenvalueMatrix(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def pseudoEigenvectors(self) -> object: 
        """
        pseudoEigenvectors( (EigenSolver)self) -> object :
            Returns the pseudo-eigenvectors of given matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> pseudoEigenvectors(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def setMaxIterations(self, max_iter: int) -> EigenSolver: 
        """
        setMaxIterations( (EigenSolver)self, (int)max_iter) -> EigenSolver :
            Sets the maximum number of iterations allowed.

            C++ signature :
                Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} setMaxIterations(Eigen::EigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},long)
        """
    pass

class Exception(Boost.Python.instance):
    @staticmethod
    def __init__(arg1: object, arg2: str) -> None: 
        """
        __init__( (object)arg1, (str)arg2) -> None :

            C++ signature :
                void __init__(_object*,std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> >)
        """
    @property
    def message(self) -> None:
        """
        :type: None
        """
    __instance_size__ = 72
    pass

class FullPivHouseholderQR(Boost.Python.instance):
    """
    This class performs a rank-revealing QR decomposition of a matrix A into matrices P, P', Q and R such that:
    PAP′=QR
    by using Householder transformations. Here, P and P' are permutation matrices, Q a unitary matrix and R an upper triangular matrix.

    This decomposition performs a very prudent full pivoting in order to be rank-revealing and achieve optimal numerical stability. The trade-off is that it is slower than HouseholderQR and ColPivHouseholderQR.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor.
            The default constructor is useful in cases in which the user intends to perform decompositions via HouseholderQR.compute(matrix)

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,long,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def __init__(self, matrix: numpy.ndarray) -> None: ...
    @typing.overload
    def __init__(self, rows: int, cols: int) -> None: ...
    def absDeterminant(self) -> float: 
        """
        absDeterminant( (FullPivHouseholderQR)self) -> float :
            Returns the absolute value of the determinant of the matrix of which *this is the QR decomposition.
            It has only linear complexity (that is, O(n) where n is the dimension of the square matrix) as the QR decomposition has already been computed.
            Note: This is only for square matrices.

            C++ signature :
                double absDeterminant(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def compute(self, matrix: numpy.ndarray) -> FullPivHouseholderQR: 
        """
        compute( (FullPivHouseholderQR)self, (numpy.ndarray)matrix) -> FullPivHouseholderQR :
            Computes the QR factorization of given matrix.

            C++ signature :
                Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} compute(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def dimensionOfKernel(self) -> int: 
        """
        dimensionOfKernel( (FullPivHouseholderQR)self) -> int :
            Returns the dimension of the kernel of the matrix of which *this is the QR decomposition.

            C++ signature :
                long dimensionOfKernel(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def id(self) -> int: 
        """
        id( (FullPivHouseholderQR)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def inverse(self) -> numpy.ndarray: 
        """
        inverse( (FullPivHouseholderQR)self) -> numpy.ndarray :
            Returns the inverse of the matrix associated with the QR decomposition..

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> inverse(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def isInjective(self) -> bool: 
        """
        isInjective( (FullPivHouseholderQR)self) -> bool :
            Returns true if the matrix associated with this QR decomposition represents an injective linear map, i.e. has trivial kernel; false otherwise.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isInjective(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def isInvertible(self) -> bool: 
        """
        isInvertible( (FullPivHouseholderQR)self) -> bool :
            Returns true if the matrix associated with the QR decomposition is invertible.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isInvertible(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def isSurjective(self) -> bool: 
        """
        isSurjective( (FullPivHouseholderQR)self) -> bool :
            Returns true if the matrix associated with this QR decomposition represents a surjective linear map; false otherwise.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                bool isSurjective(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def logAbsDeterminant(self) -> float: 
        """
        logAbsDeterminant( (FullPivHouseholderQR)self) -> float :
            Returns the natural log of the absolute value of the determinant of the matrix of which *this is the QR decomposition.
            It has only linear complexity (that is, O(n) where n is the dimension of the square matrix) as the QR decomposition has already been computed.
            Note: This is only for square matrices. This method is useful to work around the risk of overflow/underflow that's inherent to determinant computation.

            C++ signature :
                double logAbsDeterminant(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def matrixQR(self) -> numpy.ndarray: 
        """
        matrixQR( (FullPivHouseholderQR)self) -> numpy.ndarray :
            Returns the matrix where the Householder QR decomposition is stored in a LAPACK-compatible way.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixQR(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def maxPivot(self) -> float: 
        """
        maxPivot( (FullPivHouseholderQR)self) -> float :
            Returns the absolute value of the biggest pivot, i.e. the biggest diagonal coefficient of U.

            C++ signature :
                double maxPivot(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def nonzeroPivots(self) -> int: 
        """
        nonzeroPivots( (FullPivHouseholderQR)self) -> int :
            Returns the number of nonzero pivots in the QR decomposition. Here nonzero is meant in the exact sense, not in a fuzzy sense. So that notion isn't really intrinsically interesting, but it is still useful when implementing algorithms.

            C++ signature :
                long nonzeroPivots(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def rank(self) -> int: 
        """
        rank( (FullPivHouseholderQR)self) -> int :
            Returns the rank of the matrix associated with the QR decomposition.
            
            Note: This method has to determine which pivots should be considered nonzero. For that, it uses the threshold value that you can control by calling setThreshold(threshold).

            C++ signature :
                long rank(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def setThreshold(self, threshold: float) -> FullPivHouseholderQR: 
        """
        setThreshold( (FullPivHouseholderQR)self, (float)threshold) -> FullPivHouseholderQR :
            Allows to prescribe a threshold to be used by certain methods, such as rank(), who need to determine when pivots are to be considered nonzero. This is not used for the QR decomposition itself.
            
            When it needs to get the threshold value, Eigen calls threshold(). By default, this uses a formula to automatically determine a reasonable threshold. Once you have called the present method setThreshold(const RealScalar&), your value is used instead.
            
            Note: A pivot will be considered nonzero if its absolute value is strictly greater than |pivot| ⩽ threshold×|maxpivot| where maxpivot is the biggest pivot.

            C++ signature :
                Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} setThreshold(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},double)
        """
    def solve(self, B: numpy.ndarray) -> numpy.ndarray: 
        """
        solve( (FullPivHouseholderQR)self, (numpy.ndarray)B) -> numpy.ndarray :
            Returns the solution X of A X = B using the current decomposition of A where B is a right hand side matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> >,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    def threshold(self) -> float: 
        """
        threshold( (FullPivHouseholderQR)self) -> float :
            Returns the threshold that will be used by certain methods such as rank().

            C++ signature :
                double threshold(Eigen::FullPivHouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    pass

class HouseholderQR(Boost.Python.instance):
    """
    This class performs a QR decomposition of a matrix A into matrices Q and R such that A=QR by using Householder transformations.
    Here, Q a unitary matrix and R an upper triangular matrix. The result is stored in a compact way compatible with LAPACK.

    Note that no pivoting is performed. This is not a rank-revealing decomposition. If you want that feature, use FullPivHouseholderQR or ColPivHouseholderQR instead.

    This Householder QR decomposition is faster, but less numerically stable and less feature-full than FullPivHouseholderQR or ColPivHouseholderQR.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor.
            The default constructor is useful in cases in which the user intends to perform decompositions via HouseholderQR.compute(matrix)

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,long,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def __init__(self, matrix: numpy.ndarray) -> None: ...
    @typing.overload
    def __init__(self, rows: int, cols: int) -> None: ...
    def absDeterminant(self) -> float: 
        """
        absDeterminant( (HouseholderQR)self) -> float :
            Returns the absolute value of the determinant of the matrix of which *this is the QR decomposition.
            It has only linear complexity (that is, O(n) where n is the dimension of the square matrix) as the QR decomposition has already been computed.
            Note: This is only for square matrices.

            C++ signature :
                double absDeterminant(Eigen::HouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def compute(self, matrix: numpy.ndarray) -> HouseholderQR: 
        """
        compute( (HouseholderQR)self, (numpy.ndarray)matrix) -> HouseholderQR :
            Computes the QR factorization of given matrix.

            C++ signature :
                Eigen::HouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} compute(Eigen::HouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def id(self) -> int: 
        """
        id( (HouseholderQR)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::HouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def logAbsDeterminant(self) -> float: 
        """
        logAbsDeterminant( (HouseholderQR)self) -> float :
            Returns the natural log of the absolute value of the determinant of the matrix of which *this is the QR decomposition.
            It has only linear complexity (that is, O(n) where n is the dimension of the square matrix) as the QR decomposition has already been computed.
            Note: This is only for square matrices. This method is useful to work around the risk of overflow/underflow that's inherent to determinant computation.

            C++ signature :
                double logAbsDeterminant(Eigen::HouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def matrixQR(self) -> numpy.ndarray: 
        """
        matrixQR( (HouseholderQR)self) -> numpy.ndarray :
            Returns the matrix where the Householder QR decomposition is stored in a LAPACK-compatible way.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixQR(Eigen::HouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def solve(self, B: numpy.ndarray) -> numpy.ndarray: 
        """
        solve( (HouseholderQR)self, (numpy.ndarray)B) -> numpy.ndarray :
            Returns the solution X of A X = B using the current decomposition of A where B is a right hand side matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::HouseholderQR<Eigen::Matrix<double, -1, -1, 0, -1, -1> >,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    pass

class LDLT(Boost.Python.instance):
    """
    Robust Cholesky decomposition of a matrix with pivoting.

    Perform a robust Cholesky decomposition of a positive semidefinite or negative semidefinite matrix $ A $ such that $ A = P^TLDL^*P $, where P is a permutation matrix, L is lower triangular with a unit diagonal and D is a diagonal matrix.

    The decomposition uses pivoting to ensure stability, so that L will have zeros in the bottom right rank(A) - n submatrix. Avoiding the square root on D also stabilizes the computation.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def __init__(self, matrix: numpy.ndarray) -> None: ...
    @typing.overload
    def __init__(self, size: int) -> None: ...
    def adjoint(self) -> LDLT: 
        """
        adjoint( (LDLT)self) -> LDLT :
            Returns the adjoint, that is, a reference to the decomposition itself as if the underlying matrix is self-adjoint.

            C++ signature :
                Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue} adjoint(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def cols(self) -> int: 
        """
        cols( (LDLT)self) -> int :
            Returns the number of columns.

            C++ signature :
                long cols(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def compute(self, matrix: numpy.ndarray) -> LDLT: 
        """
        compute( (LDLT)self, (numpy.ndarray)matrix) -> LDLT :
            Computes the LDLT of given matrix.

            C++ signature :
                Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue} compute(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def id(self) -> int: 
        """
        id( (LDLT)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>)
        """
    def info(self) -> ComputationInfo: 
        """
        info( (LDLT)self) -> ComputationInfo :
            NumericalIssue if the input contains INF or NaN values or overflow occured. Returns Success otherwise.

            C++ signature :
                Eigen::ComputationInfo info(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def isNegative(self) -> bool: 
        """
        isNegative( (LDLT)self) -> bool :
            Returns true if the matrix is negative (semidefinite).

            C++ signature :
                bool isNegative(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def isPositive(self) -> bool: 
        """
        isPositive( (LDLT)self) -> bool :
            Returns true if the matrix is positive (semidefinite).

            C++ signature :
                bool isPositive(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def matrixL(self) -> numpy.ndarray: 
        """
        matrixL( (LDLT)self) -> numpy.ndarray :
            Returns the lower triangular matrix L.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixL(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>)
        """
    def matrixLDLT(self) -> object: 
        """
        matrixLDLT( (LDLT)self) -> object :
            Returns the LDLT decomposition matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixLDLT(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def matrixU(self) -> numpy.ndarray: 
        """
        matrixU( (LDLT)self) -> numpy.ndarray :
            Returns the upper triangular matrix U.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixU(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>)
        """
    def rankUpdate(self, vector: numpy.ndarray, sigma: float) -> LDLT: 
        """
        rankUpdate( (LDLT)self, (numpy.ndarray)vector, (float)sigma) -> LDLT :

            C++ signature :
                Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue} rankUpdate(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue},Eigen::MatrixBase<Eigen::Matrix<double, -1, 1, 0, -1, 1> >,double)
        """
    def rcond(self) -> float: 
        """
        rcond( (LDLT)self) -> float :
            Returns an estimate of the reciprocal condition number of the matrix.

            C++ signature :
                double rcond(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def reconstructedMatrix(self) -> numpy.ndarray: 
        """
        reconstructedMatrix( (LDLT)self) -> numpy.ndarray :
            Returns the matrix represented by the decomposition, i.e., it returns the product: L L^*. This function is provided for debug purpose.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> reconstructedMatrix(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def rows(self) -> int: 
        """
        rows( (LDLT)self) -> int :
            Returns the number of rows.

            C++ signature :
                long rows(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def setZero(self) -> None: 
        """
        setZero( (LDLT)self) -> None :
            Clear any existing decomposition.

            C++ signature :
                void setZero(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def size(self) -> int: 
        """
        size( (LDLT)self) -> int :
            Returns the number of coefficients, which is rows()*cols().

            C++ signature :
                long size(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    @typing.overload
    def solve(self, B: numpy.ndarray) -> numpy.ndarray: 
        """
        solve( (LDLT)self, (numpy.ndarray)b) -> numpy.ndarray :
            Returns the solution x of A x = b using the current decomposition of A.

            C++ signature :
                Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>,Eigen::Matrix<double, -1, 1, 0, -1, 1>)

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def solve(self, b: numpy.ndarray) -> numpy.ndarray: ...
    def transpositionsP(self) -> numpy.ndarray: 
        """
        transpositionsP( (LDLT)self) -> numpy.ndarray :
            Returns the permutation matrix P.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> transpositionsP(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>)
        """
    def vectorD(self) -> numpy.ndarray: 
        """
        vectorD( (LDLT)self) -> numpy.ndarray :
            Returns the coefficients of the diagonal matrix D.

            C++ signature :
                Eigen::Matrix<double, -1, 1, 0, -1, 1> vectorD(Eigen::LDLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>)
        """
    pass

class LLT(Boost.Python.instance):
    """
    Standard Cholesky decomposition (LL^T) of a matrix and associated features.

    This class performs a LL^T Cholesky decomposition of a symmetric, positive definite matrix A such that A = LL^* = U^*U, where L is lower triangular.

    While the Cholesky decomposition is particularly useful to solve selfadjoint problems like D^*D x = b, for that purpose, we recommend the Cholesky decomposition without square root which is more stable and even faster. Nevertheless, this standard Cholesky decomposition remains useful in many other situations like generalised eigen problems with hermitian matrices.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def __init__(self, matrix: numpy.ndarray) -> None: ...
    @typing.overload
    def __init__(self, size: int) -> None: ...
    def adjoint(self) -> LLT: 
        """
        adjoint( (LLT)self) -> LLT :
            Returns the adjoint, that is, a reference to the decomposition itself as if the underlying matrix is self-adjoint.

            C++ signature :
                Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue} adjoint(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def cols(self) -> int: 
        """
        cols( (LLT)self) -> int :
            Returns the number of columns.

            C++ signature :
                long cols(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def compute(self, matrix: numpy.ndarray) -> LLT: 
        """
        compute( (LLT)self, (numpy.ndarray)matrix) -> LLT :
            Computes the LLT of given matrix.

            C++ signature :
                Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue} compute(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def id(self) -> int: 
        """
        id( (LLT)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>)
        """
    def info(self) -> ComputationInfo: 
        """
        info( (LLT)self) -> ComputationInfo :
            NumericalIssue if the input contains INF or NaN values or overflow occured. Returns Success otherwise.

            C++ signature :
                Eigen::ComputationInfo info(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def matrixL(self) -> numpy.ndarray: 
        """
        matrixL( (LLT)self) -> numpy.ndarray :
            Returns the lower triangular matrix L.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixL(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>)
        """
    def matrixLLT(self) -> object: 
        """
        matrixLLT( (LLT)self) -> object :
            Returns the LLT decomposition matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixLLT(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def matrixU(self) -> numpy.ndarray: 
        """
        matrixU( (LLT)self) -> numpy.ndarray :
            Returns the upper triangular matrix U.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> matrixU(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>)
        """
    def rankUpdate(self, vector: numpy.ndarray, sigma: float) -> LLT: 
        """
        rankUpdate( (LLT)self, (numpy.ndarray)vector, (float)sigma) -> LLT :

            C++ signature :
                Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue} rankUpdate(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>,double)
        """
    def rcond(self) -> float: 
        """
        rcond( (LLT)self) -> float :
            Returns an estimate of the reciprocal condition number of the matrix.

            C++ signature :
                double rcond(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def reconstructedMatrix(self) -> numpy.ndarray: 
        """
        reconstructedMatrix( (LLT)self) -> numpy.ndarray :
            Returns the matrix represented by the decomposition, i.e., it returns the product: L L^*. This function is provided for debug purpose.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> reconstructedMatrix(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def rows(self) -> int: 
        """
        rows( (LLT)self) -> int :
            Returns the number of rows.

            C++ signature :
                long rows(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    def size(self) -> int: 
        """
        size( (LLT)self) -> int :
            Returns the number of coefficients, which is rows()*cols().

            C++ signature :
                long size(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1> {lvalue})
        """
    @typing.overload
    def solve(self, B: numpy.ndarray) -> numpy.ndarray: 
        """
        solve( (LLT)self, (numpy.ndarray)b) -> numpy.ndarray :
            Returns the solution x of A x = b using the current decomposition of A.

            C++ signature :
                Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>,Eigen::Matrix<double, -1, 1, 0, -1, 1>)

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::LLT<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1>,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def solve(self, b: numpy.ndarray) -> numpy.ndarray: ...
    pass

class MINRES(Boost.Python.instance):
    """
    A minimal residual solver for sparse symmetric problems.
    This class allows to solve for A.x = b sparse linear problems using the MINRES algorithm of Paige and Saunders (1975). The sparse matrix A must be symmetric (possibly indefinite). The vectors x and b can be either dense or sparse.
    The maximal number of iterations and tolerance value can be controlled via the setMaxIterations() and setTolerance() methods. The defaults are the size of the problem for the maximal number of iterations and NumTraits<Scalar>::epsilon() for the tolerance.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    @typing.overload
    def __init__(self, matrix: numpy.ndarray) -> None: ...
    def analyzePattern(self, A: numpy.ndarray) -> MINRES: 
        """
        analyzePattern( (MINRES)self, (numpy.ndarray)A) -> MINRES :
            Initializes the iterative solver for the sparsity pattern of the matrix A for further solving Ax=b problems.

            C++ signature :
                Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue} analyzePattern(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def cols(self) -> int: 
        """
        cols( (MINRES)self) -> int :
            Returns the number of columns.

            C++ signature :
                long cols(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue})
        """
    def compute(self, A: numpy.ndarray) -> MINRES: 
        """
        compute( (MINRES)self, (numpy.ndarray)A) -> MINRES :
            Initializes the iterative solver with the matrix A for further solving Ax=b problems.

            C++ signature :
                Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue} compute(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def error(self) -> float: 
        """
        error( (MINRES)self) -> float :
            Returns the tolerance error reached during the last solve.
            It is a close approximation of the true relative residual error |Ax-b|/|b|.

            C++ signature :
                double error(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue})
        """
    def factorize(self, A: numpy.ndarray) -> MINRES: 
        """
        factorize( (MINRES)self, (numpy.ndarray)A) -> MINRES :
            Initializes the iterative solver with the numerical values of the matrix A for further solving Ax=b problems.

            C++ signature :
                Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue} factorize(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def id(self) -> int: 
        """
        id( (MINRES)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner>)
        """
    @staticmethod
    def info(info: MINRES) -> float: 
        """
        info( (MINRES)info) -> float :
            Returns Success if the iterations converged, and NoConvergence otherwise.

            C++ signature :
                double info(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue})
        """
    def iterations(self) -> int: 
        """
        iterations( (MINRES)self) -> int :
            Returns the number of iterations performed during the last solve.

            C++ signature :
                long iterations(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue})
        """
    def maxIterations(self) -> int: 
        """
        maxIterations( (MINRES)self) -> int :
            Returns the max number of iterations.
            It is either the value setted by setMaxIterations or, by default, twice the number of columns of the matrix.

            C++ signature :
                long maxIterations(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue})
        """
    def preconditioner(self) -> IdentityPreconditioner: 
        """
        preconditioner( (MINRES)self) -> IdentityPreconditioner :
            Returns a read-write reference to the preconditioner for custom configuration.

            C++ signature :
                Eigen::IdentityPreconditioner {lvalue} preconditioner(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue})
        """
    def rows(self) -> int: 
        """
        rows( (MINRES)self) -> int :
            Returns the number of rows.

            C++ signature :
                long rows(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue})
        """
    def setMaxIterations(self, max_iterations: int) -> MINRES: 
        """
        setMaxIterations( (MINRES)self, (int)max_iterations) -> MINRES :
            Sets the max number of iterations.
            Default is twice the number of columns of the matrix.

            C++ signature :
                Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue} setMaxIterations(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue},long)
        """
    def setTolerance(self, tolerance: float) -> MINRES: 
        """
        setTolerance( (MINRES)self, (float)tolerance) -> MINRES :
            Sets the tolerance threshold used by the stopping criteria.
            This value is used as an upper bound to the relative residual error: |Ax-b|/|b|.
            The default value is the machine precision given by NumTraits<Scalar>::epsilon().

            C++ signature :
                Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue} setTolerance(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue},double)
        """
    def solve(self, b: numpy.ndarray) -> numpy.ndarray: 
        """
        solve( (MINRES)self, (numpy.ndarray)b) -> numpy.ndarray :
            Returns the solution x of A x = b using the current decomposition of A where b is a right hand side matrix or vector.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner>,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    def solveWithGuess(self, b: numpy.ndarray, x0: numpy.ndarray) -> numpy.ndarray: 
        """
        solveWithGuess( (MINRES)self, (numpy.ndarray)b, (numpy.ndarray)x0) -> numpy.ndarray :
            Returns the solution x of A x = b using the current decomposition of A and x0 as an initial solution.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solveWithGuess(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner>,Eigen::Matrix<double, -1, -1, 0, -1, -1>,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
        """
    def tolerance(self) -> float: 
        """
        tolerance( (MINRES)self) -> float :
            Returns the tolerance threshold used by the stopping criteria.

            C++ signature :
                double tolerance(Eigen::MINRES<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 1, Eigen::IdentityPreconditioner> {lvalue})
        """
    pass

class PermutationMatrix(Boost.Python.instance):
    """
    Permutation matrix.
    This class represents a permutation matrix, internally stored as a vector of integers.
    """
    @typing.overload
    def __init__(self, indices: numpy.ndarray) -> None: 
        """
        __init__( (object)self, (int)size) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<int, -1, 1, 0, -1, 1>)
        """
    @typing.overload
    def __init__(self, size: int) -> None: ...
    @staticmethod
    def __mul__(arg1: PermutationMatrix, arg2: PermutationMatrix) -> object: 
        """
        __mul__( (PermutationMatrix)arg1, (PermutationMatrix)arg2) -> object :

            C++ signature :
                _object* __mul__(Eigen::PermutationMatrix<-1, -1, int> {lvalue},Eigen::PermutationMatrix<-1, -1, int>)
        """
    def applyTranspositionOnTheLeft(self, i: int, j: int) -> PermutationMatrix: 
        """
        applyTranspositionOnTheLeft( (PermutationMatrix)self, (int)i, (int)j) -> PermutationMatrix :
            Multiplies self by the transposition (ij) on the left.

            C++ signature :
                Eigen::PermutationMatrix<-1, -1, int> {lvalue} applyTranspositionOnTheLeft(Eigen::PermutationMatrix<-1, -1, int> {lvalue},long,long)
        """
    def applyTranspositionOnTheRight(self, i: int, j: int) -> PermutationMatrix: 
        """
        applyTranspositionOnTheRight( (PermutationMatrix)self, (int)i, (int)j) -> PermutationMatrix :
            Multiplies self by the transposition (ij) on the right.

            C++ signature :
                Eigen::PermutationMatrix<-1, -1, int> {lvalue} applyTranspositionOnTheRight(Eigen::PermutationMatrix<-1, -1, int> {lvalue},long,long)
        """
    def cols(self) -> int: 
        """
        cols( (PermutationMatrix)self) -> int :
            Returns the number of columns.

            C++ signature :
                long cols(Eigen::PermutationMatrix<-1, -1, int> {lvalue})
        """
    def id(self) -> int: 
        """
        id( (PermutationMatrix)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::PermutationMatrix<-1, -1, int>)
        """
    def indices(self) -> numpy.ndarray: 
        """
        indices( (PermutationMatrix)self) -> numpy.ndarray :
            The stored array representing the permutation.

            C++ signature :
                Eigen::Matrix<int, -1, 1, 0, -1, 1> indices(Eigen::PermutationMatrix<-1, -1, int>)
        """
    def inverse(self) -> PermutationMatrix: 
        """
        inverse( (PermutationMatrix)self) -> PermutationMatrix :
            Returns the inverse permutation matrix.

            C++ signature :
                Eigen::PermutationMatrix<-1, -1, int> inverse(Eigen::PermutationMatrix<-1, -1, int>)
        """
    def resize(self, size: int) -> None: 
        """
        resize( (PermutationMatrix)self, (int)size) -> None :
            Resizes to given size.

            C++ signature :
                void resize(Eigen::PermutationMatrix<-1, -1, int> {lvalue},long)
        """
    def rows(self) -> int: 
        """
        rows( (PermutationMatrix)self) -> int :
            Returns the number of rows.

            C++ signature :
                long rows(Eigen::PermutationMatrix<-1, -1, int> {lvalue})
        """
    @typing.overload
    def setIdentity(self) -> None: 
        """
        setIdentity( (PermutationMatrix)self) -> None :
            Sets self to be the identity permutation matrix.

            C++ signature :
                void setIdentity(Eigen::PermutationMatrix<-1, -1, int> {lvalue})

            C++ signature :
                void setIdentity(Eigen::PermutationMatrix<-1, -1, int> {lvalue},long)
        """
    @typing.overload
    def setIdentity(self, size: int) -> None: ...
    def size(self) -> int: 
        """
        size( (PermutationMatrix)self) -> int :
            Returns the number of coefficients, which is rows()*cols().

            C++ signature :
                long size(Eigen::PermutationMatrix<-1, -1, int> {lvalue})
        """
    def toDenseMatrix(self) -> numpy.ndarray: 
        """
        toDenseMatrix( (PermutationMatrix)self) -> numpy.ndarray :
            Returns a numpy array object initialized from this permutation matrix.

            C++ signature :
                Eigen::Matrix<int, -1, -1, 0, -1, -1> toDenseMatrix(Eigen::PermutationMatrix<-1, -1, int> {lvalue})
        """
    def transpose(self) -> PermutationMatrix: 
        """
        transpose( (PermutationMatrix)self) -> PermutationMatrix :
            Returns the tranpose permutation matrix.

            C++ signature :
                Eigen::PermutationMatrix<-1, -1, int> transpose(Eigen::PermutationMatrix<-1, -1, int>)
        """
    pass

class Quaternion(Boost.Python.instance):
    """
    Quaternion representing rotation.

    Supported operations ('q is a Quaternion, 'v' is a Vector3): 'q*q' (rotation composition), 'q*=q', 'q*v' (rotating 'v' by 'q'), 'q==q', 'q!=q', 'q[0..3]'.
    """
    @staticmethod
    def FromTwoVectors(a: numpy.ndarray, b: numpy.ndarray) -> Quaternion: 
        """
        FromTwoVectors( (numpy.ndarray)a, (numpy.ndarray)b) -> Quaternion :
            Returns the quaternion which transforms a into b through a rotation.

            C++ signature :
                Eigen::Quaternion<double, 0>* FromTwoVectors(Eigen::Ref<Eigen::Matrix<double, 3, 1, 0, 3, 1> const, 0, Eigen::InnerStride<1> >,Eigen::Ref<Eigen::Matrix<double, 3, 1, 0, 3, 1> const, 0, Eigen::InnerStride<1> >)
        """
    @staticmethod
    def Identity() -> Quaternion: 
        """
        Identity() -> Quaternion :
            Returns a quaternion representing an identity rotation.

            C++ signature :
                Eigen::Quaternion<double, 0>* Identity()
        """
    @staticmethod
    def __abs__(arg1: Quaternion) -> float: 
        """
        __abs__( (Quaternion)arg1) -> float :

            C++ signature :
                double __abs__(Eigen::Quaternion<double, 0> {lvalue})
        """
    @staticmethod
    def __eq__(arg1: Quaternion, arg2: Quaternion) -> bool: 
        """
        __eq__( (Quaternion)arg1, (Quaternion)arg2) -> bool :

            C++ signature :
                bool __eq__(Eigen::Quaternion<double, 0>,Eigen::Quaternion<double, 0>)
        """
    @staticmethod
    def __getitem__(arg1: Quaternion, arg2: int) -> float: 
        """
        __getitem__( (Quaternion)arg1, (int)arg2) -> float :

            C++ signature :
                double __getitem__(Eigen::Quaternion<double, 0>,int)
        """
    @staticmethod
    def __imul__(arg1: object, arg2: Quaternion) -> object: 
        """
        __imul__( (object)arg1, (Quaternion)arg2) -> object :

            C++ signature :
                _object* __imul__(boost::python::back_reference<Eigen::Quaternion<double, 0>&>,Eigen::Quaternion<double, 0>)
        """
    @staticmethod
    @typing.overload
    def __init__(arg1: object) -> object: 
        """
        __init__( (object)arg1, (numpy.ndarray)R) -> object :
            Initialize from rotation matrix.
            	R : a rotation matrix 3x3.

            C++ signature :
                void* __init__(boost::python::api::object,Eigen::Ref<Eigen::Matrix<double, 3, 3, 0, 3, 3> const, 0, Eigen::OuterStride<-1> >)

            C++ signature :
                void* __init__(boost::python::api::object,Eigen::AngleAxis<double>)

            C++ signature :
                void* __init__(boost::python::api::object,Eigen::Quaternion<double, 0>)

            C++ signature :
                void* __init__(boost::python::api::object,Eigen::Ref<Eigen::Matrix<double, 3, 1, 0, 3, 1> const, 0, Eigen::InnerStride<1> >,Eigen::Ref<Eigen::Matrix<double, 3, 1, 0, 3, 1> const, 0, Eigen::InnerStride<1> >)

            C++ signature :
                void* __init__(boost::python::api::object,Eigen::Ref<Eigen::Matrix<double, 4, 1, 0, 4, 1> const, 0, Eigen::InnerStride<1> >)

            C++ signature :
                void* __init__(boost::python::api::object)

            C++ signature :
                void* __init__(boost::python::api::object,double,double,double,double)
        """
    @staticmethod
    @typing.overload
    def __init__(arg1: object, R: numpy.ndarray) -> object: ...
    @staticmethod
    @typing.overload
    def __init__(arg1: object, aa: AngleAxis) -> object: ...
    @staticmethod
    @typing.overload
    def __init__(arg1: object, quat: Quaternion) -> object: ...
    @staticmethod
    @typing.overload
    def __init__(arg1: object, u: numpy.ndarray, v: numpy.ndarray) -> object: ...
    @staticmethod
    @typing.overload
    def __init__(arg1: object, vec4: numpy.ndarray) -> object: ...
    @staticmethod
    @typing.overload
    def __init__(arg1: object, w: float, x: float, y: float, z: float) -> object: ...
    @staticmethod
    def __len__() -> int: 
        """
        __len__() -> int :

            C++ signature :
                int __len__()
        """
    @staticmethod
    @typing.overload
    def __mul__(arg1: Quaternion, arg2: Quaternion) -> object: 
        """
        __mul__( (Quaternion)arg1, (Quaternion)arg2) -> object :

            C++ signature :
                _object* __mul__(Eigen::Quaternion<double, 0> {lvalue},Eigen::Quaternion<double, 0>)

            C++ signature :
                _object* __mul__(Eigen::Quaternion<double, 0> {lvalue},Eigen::Matrix<double, 3, 1, 0, 3, 1>)
        """
    @staticmethod
    @typing.overload
    def __mul__(arg1: Quaternion, arg2: numpy.ndarray) -> object: ...
    @staticmethod
    def __ne__(arg1: Quaternion, arg2: Quaternion) -> bool: 
        """
        __ne__( (Quaternion)arg1, (Quaternion)arg2) -> bool :

            C++ signature :
                bool __ne__(Eigen::Quaternion<double, 0>,Eigen::Quaternion<double, 0>)
        """
    @staticmethod
    def __repr__(arg1: Quaternion) -> str: 
        """
        __repr__( (Quaternion)arg1) -> str :

            C++ signature :
                std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > __repr__(Eigen::Quaternion<double, 0>)
        """
    @staticmethod
    def __setitem__(arg1: Quaternion, arg2: int, arg3: float) -> None: 
        """
        __setitem__( (Quaternion)arg1, (int)arg2, (float)arg3) -> None :

            C++ signature :
                void __setitem__(Eigen::Quaternion<double, 0> {lvalue},int,double)
        """
    @staticmethod
    def __str__(arg1: Quaternion) -> str: 
        """
        __str__( (Quaternion)arg1) -> str :

            C++ signature :
                std::__cxx11::basic_string<char, std::char_traits<char>, std::allocator<char> > __str__(Eigen::Quaternion<double, 0>)
        """
    def _transformVector(self, vector: numpy.ndarray) -> numpy.ndarray: 
        """
        _transformVector( (Quaternion)self, (numpy.ndarray)vector) -> numpy.ndarray :
            Rotation of a vector by a quaternion.

            C++ signature :
                Eigen::Matrix<double, 3, 1, 0, 3, 1> _transformVector(Eigen::Quaternion<double, 0> {lvalue},Eigen::Matrix<double, 3, 1, 0, 3, 1>)
        """
    @staticmethod
    def angularDistance(arg1: Quaternion, arg2: Quaternion) -> float: 
        """
        angularDistance( (Quaternion)arg1, (Quaternion)arg2) -> float :
            Returns the angle (in radian) between two rotations.

            C++ signature :
                double angularDistance(Eigen::Quaternion<double, 0> {lvalue},Eigen::QuaternionBase<Eigen::Quaternion<double, 0> >)
        """
    @typing.overload
    def assign(self, aa: AngleAxis) -> Quaternion: 
        """
        assign( (Quaternion)self, (Quaternion)quat) -> Quaternion :
            Set *this from an quaternion quat and returns a reference to *this.

            C++ signature :
                Eigen::Quaternion<double, 0> {lvalue} assign(Eigen::Quaternion<double, 0> {lvalue},Eigen::Quaternion<double, 0>)

            C++ signature :
                Eigen::Quaternion<double, 0> {lvalue} assign(Eigen::Quaternion<double, 0> {lvalue},Eigen::AngleAxis<double>)
        """
    @typing.overload
    def assign(self, quat: Quaternion) -> Quaternion: ...
    def coeffs(self) -> object: 
        """
        coeffs( (Quaternion)self) -> object :
            Returns a vector of the coefficients (x,y,z,w)

            C++ signature :
                Eigen::Matrix<double, 4, 1, 0, 4, 1> coeffs(Eigen::Quaternion<double, 0> {lvalue})
        """
    def conjugate(self) -> Quaternion: 
        """
        conjugate( (Quaternion)self) -> Quaternion :
            Returns the conjugated quaternion.
            The conjugate of a quaternion represents the opposite rotation.

            C++ signature :
                Eigen::Quaternion<double, 0> conjugate(Eigen::Quaternion<double, 0> {lvalue})
        """
    def dot(self, other: Quaternion) -> float: 
        """
        dot( (Quaternion)self, (Quaternion)other) -> float :
            Returns the dot product of *this with an other Quaternion.
            Geometrically speaking, the dot product of two unit quaternions corresponds to the cosine of half the angle between the two rotations.

            C++ signature :
                double dot(Eigen::Quaternion<double, 0> {lvalue},Eigen::QuaternionBase<Eigen::Quaternion<double, 0> >)
        """
    def id(self) -> int: 
        """
        id( (Quaternion)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::Quaternion<double, 0>)
        """
    def inverse(self) -> Quaternion: 
        """
        inverse( (Quaternion)self) -> Quaternion :
            Returns the quaternion describing the inverse rotation.

            C++ signature :
                Eigen::Quaternion<double, 0> inverse(Eigen::Quaternion<double, 0> {lvalue})
        """
    def isApprox(self, other_: Quaternion, prec: float) -> bool: 
        """
        isApprox( (Quaternion)self, (Quaternion)other [, (float)prec]) -> bool :
            Returns true if *this is approximately equal to other, within the precision determined by prec.

            C++ signature :
                bool isApprox(Eigen::Quaternion<double, 0>,Eigen::Quaternion<double, 0> [,double])
        """
    def matrix(self) -> numpy.ndarray: 
        """
        matrix( (Quaternion)self) -> numpy.ndarray :
            Returns an equivalent 3x3 rotation matrix. Similar to toRotationMatrix.

            C++ signature :
                Eigen::Matrix<double, 3, 3, 0, 3, 3> matrix(Eigen::Quaternion<double, 0> {lvalue})
        """
    def norm(self) -> float: 
        """
        norm( (Quaternion)self) -> float :
            Returns the norm of the quaternion's coefficients.

            C++ signature :
                double norm(Eigen::Quaternion<double, 0> {lvalue})
        """
    def normalize(self) -> Quaternion: 
        """
        normalize( (Quaternion)self) -> Quaternion :
            Normalizes the quaternion *this.

            C++ signature :
                Eigen::Quaternion<double, 0> {lvalue} normalize(Eigen::Quaternion<double, 0> {lvalue})
        """
    def normalized(self) -> Quaternion: 
        """
        normalized( (Quaternion)self) -> Quaternion :
            Returns a normalized copy of *this.

            C++ signature :
                Eigen::Quaternion<double, 0>* normalized(Eigen::Quaternion<double, 0>)
        """
    def setFromTwoVectors(self, a: numpy.ndarray, b: numpy.ndarray) -> Quaternion: 
        """
        setFromTwoVectors( (Quaternion)self, (numpy.ndarray)a, (numpy.ndarray)b) -> Quaternion :
            Set *this to be the quaternion which transforms a into b through a rotation.

            C++ signature :
                Eigen::Quaternion<double, 0> {lvalue} setFromTwoVectors(Eigen::Quaternion<double, 0> {lvalue},Eigen::Matrix<double, 3, 1, 0, 3, 1>,Eigen::Matrix<double, 3, 1, 0, 3, 1>)
        """
    def setIdentity(self) -> Quaternion: 
        """
        setIdentity( (Quaternion)self) -> Quaternion :
            Set *this to the identity rotation.

            C++ signature :
                Eigen::Quaternion<double, 0> {lvalue} setIdentity(Eigen::Quaternion<double, 0> {lvalue})
        """
    def slerp(self, t: float, other: Quaternion) -> Quaternion: 
        """
        slerp( (Quaternion)self, (float)t, (Quaternion)other) -> Quaternion :
            Returns the spherical linear interpolation between the two quaternions *this and other at the parameter t in [0;1].

            C++ signature :
                Eigen::Quaternion<double, 0> slerp(Eigen::Quaternion<double, 0>,double,Eigen::Quaternion<double, 0>)
        """
    def squaredNorm(self) -> float: 
        """
        squaredNorm( (Quaternion)self) -> float :
            Returns the squared norm of the quaternion's coefficients.

            C++ signature :
                double squaredNorm(Eigen::Quaternion<double, 0> {lvalue})
        """
    @staticmethod
    def toRotationMatrix(arg1: Quaternion) -> numpy.ndarray: 
        """
        toRotationMatrix( (Quaternion)arg1) -> numpy.ndarray :
            Returns an equivalent rotation matrix.

            C++ signature :
                Eigen::Matrix<double, 3, 3, 0, 3, 3> toRotationMatrix(Eigen::Quaternion<double, 0> {lvalue})
        """
    def vec(self) -> numpy.ndarray: 
        """
        vec( (Quaternion)self) -> numpy.ndarray :
            Returns a vector expression of the imaginary part (x,y,z).

            C++ signature :
                Eigen::Matrix<double, 3, 1, 0, 3, 1> vec(Eigen::Quaternion<double, 0>)
        """
    @property
    def w(self) -> None:
        """
        The w coefficient.

        :type: None
        """
    @property
    def x(self) -> None:
        """
        The x coefficient.

        :type: None
        """
    @property
    def y(self) -> None:
        """
        The y coefficient.

        :type: None
        """
    @property
    def z(self) -> None:
        """
        The z coefficient.

        :type: None
        """
    pass

class SelfAdjointEigenSolver(Boost.Python.instance):
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,long)

            C++ signature :
                void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1> [,int])
        """
    @typing.overload
    def __init__(self, matrix_: numpy.ndarray, options: int) -> None: ...
    @typing.overload
    def __init__(self, size: int) -> None: ...
    @typing.overload
    def compute(self, matrix: numpy.ndarray) -> SelfAdjointEigenSolver: 
        """
        compute( (SelfAdjointEigenSolver)self, (numpy.ndarray)matrix) -> SelfAdjointEigenSolver :
            Computes the eigendecomposition of given matrix.

            C++ signature :
                Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} compute(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)

            C++ signature :
                Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} compute(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::EigenBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >,int)
        """
    @typing.overload
    def compute(self, matrix: numpy.ndarray, options: int) -> SelfAdjointEigenSolver: ...
    @typing.overload
    def computeDirect(self, matrix: numpy.ndarray) -> SelfAdjointEigenSolver: 
        """
        computeDirect( (SelfAdjointEigenSolver)self, (numpy.ndarray)matrix) -> SelfAdjointEigenSolver :
            Computes eigendecomposition of given matrix using a closed-form algorithm.

            C++ signature :
                Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} computeDirect(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)

            C++ signature :
                Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue} computeDirect(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>,int)
        """
    @typing.overload
    def computeDirect(self, matrix: numpy.ndarray, options: int) -> SelfAdjointEigenSolver: ...
    def eigenvalues(self) -> object: 
        """
        eigenvalues( (SelfAdjointEigenSolver)self) -> object :
            Returns the eigenvalues of given matrix.

            C++ signature :
                Eigen::Matrix<double, -1, 1, 0, -1, 1> eigenvalues(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def eigenvectors(self) -> object: 
        """
        eigenvectors( (SelfAdjointEigenSolver)self) -> object :
            Returns the eigenvectors of given matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> eigenvectors(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def id(self) -> int: 
        """
        id( (SelfAdjointEigenSolver)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> >)
        """
    def info(self) -> ComputationInfo: 
        """
        info( (SelfAdjointEigenSolver)self) -> ComputationInfo :
            NumericalIssue if the input contains INF or NaN values or overflow occured. Returns Success otherwise.

            C++ signature :
                Eigen::ComputationInfo info(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def operatorInverseSqrt(self) -> numpy.ndarray: 
        """
        operatorInverseSqrt( (SelfAdjointEigenSolver)self) -> numpy.ndarray :
            Computes the inverse square root of the matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> operatorInverseSqrt(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    def operatorSqrt(self) -> numpy.ndarray: 
        """
        operatorSqrt( (SelfAdjointEigenSolver)self) -> numpy.ndarray :
            Computes the inverse square root of the matrix.

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> operatorSqrt(Eigen::SelfAdjointEigenSolver<Eigen::Matrix<double, -1, -1, 0, -1, -1> > {lvalue})
        """
    pass

class SimplicialLDLT(Boost.Python.instance):
    """
    A direct sparse LDLT Cholesky factorizations.

    This class provides a LDL^T Cholesky factorizations of sparse matrices that are selfadjoint and positive definite.The factorization allows for solving A.X = B where X and B can be either dense or sparse.

    In order to reduce the fill-in, a symmetric permutation P is applied prior to the factorization such that the factorized matrix is P A P^-1.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,Eigen::SparseMatrix<double, 0, int>)
        """
    @typing.overload
    def __init__(self, matrix: csc_matrix) -> None: ...
    def analyzePattern(self, matrix: csc_matrix) -> None: 
        """
        analyzePattern( (SimplicialLDLT)self, (csc_matrix)matrix) -> None :
            Performs a symbolic decomposition on the sparcity of matrix.
            This function is particularly useful when solving for several problems having the same structure.

            C++ signature :
                void analyzePattern(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue},Eigen::SparseMatrix<double, 0, int>)
        """
    def cols(self) -> int: 
        """
        cols( (SimplicialLDLT)self) -> int :
            Returns the number of columns.

            C++ signature :
                long cols(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def compute(self, matrix: csc_matrix) -> SimplicialLDLT: 
        """
        compute( (SimplicialLDLT)self, (csc_matrix)matrix) -> SimplicialLDLT :
            Computes the sparse Cholesky decomposition of a given matrix.

            C++ signature :
                Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue} compute(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue},Eigen::SparseMatrix<double, 0, int>)
        """
    def determinant(self) -> float: 
        """
        determinant( (SimplicialLDLT)self) -> float :
            Returns the determinant of the underlying matrix from the current factorization.

            C++ signature :
                double determinant(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def factorize(self, matrix: csc_matrix) -> None: 
        """
        factorize( (SimplicialLDLT)self, (csc_matrix)matrix) -> None :
            Performs a numeric decomposition of a given matrix.
            The given matrix must has the same sparcity than the matrix on which the symbolic decomposition has been performed.
            See also analyzePattern().

            C++ signature :
                void factorize(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue},Eigen::SparseMatrix<double, 0, int>)
        """
    def id(self) -> int: 
        """
        id( (SimplicialLDLT)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >)
        """
    def info(self) -> ComputationInfo: 
        """
        info( (SimplicialLDLT)self) -> ComputationInfo :
            NumericalIssue if the input contains INF or NaN values or overflow occured. Returns Success otherwise.

            C++ signature :
                Eigen::ComputationInfo info(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def matrixL(self) -> csc_matrix: 
        """
        matrixL( (SimplicialLDLT)self) -> csc_matrix :
            Returns the lower triangular matrix L.

            C++ signature :
                Eigen::SparseMatrix<double, 0, int> matrixL(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >)
        """
    def matrixU(self) -> csc_matrix: 
        """
        matrixU( (SimplicialLDLT)self) -> csc_matrix :
            Returns the upper triangular matrix U.

            C++ signature :
                Eigen::SparseMatrix<double, 0, int> matrixU(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >)
        """
    def permutationP(self) -> PermutationMatrix: 
        """
        permutationP( (SimplicialLDLT)self) -> PermutationMatrix :
            Returns the permutation P.

            C++ signature :
                Eigen::PermutationMatrix<-1, -1, int> permutationP(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def permutationPinv(self) -> PermutationMatrix: 
        """
        permutationPinv( (SimplicialLDLT)self) -> PermutationMatrix :
            Returns the inverse P^-1 of the permutation P.

            C++ signature :
                Eigen::PermutationMatrix<-1, -1, int> permutationPinv(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def rows(self) -> int: 
        """
        rows( (SimplicialLDLT)self) -> int :
            Returns the number of rows.

            C++ signature :
                long rows(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def setShift(self, offset_: float, scale: float = 1.0) -> SimplicialLDLT: 
        """
        setShift( (SimplicialLDLT)self, (float)offset [, (float)scale=1.0]) -> SimplicialLDLT :
            Sets the shift parameters that will be used to adjust the diagonal coefficients during the numerical factorization.
            During the numerical factorization, the diagonal coefficients are transformed by the following linear model: d_ii = offset + scale * d_ii.
            The default is the identity transformation with offset=0, and scale=1.

            C++ signature :
                Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue} setShift(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue},double [,double=1.0])
        """
    def size(self) -> int: 
        """
        size( (SimplicialLDLT)self) -> int :
            Returns the number of coefficients, which is rows()*cols().

            C++ signature :
                long size(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    @typing.overload
    def solve(self, B: csc_matrix) -> csc_matrix: 
        """
        solve( (SimplicialLDLT)self, (numpy.ndarray)b) -> numpy.ndarray :
            Returns the solution x of A x = b using the current decomposition of A.

            C++ signature :
                Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >,Eigen::Matrix<double, -1, 1, 0, -1, 1>)

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >,Eigen::Matrix<double, -1, -1, 0, -1, -1>)

            C++ signature :
                Eigen::SparseMatrix<double, 0, int> solve(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >,Eigen::SparseMatrix<double, 0, int>)
        """
    @typing.overload
    def solve(self, B: numpy.ndarray) -> numpy.ndarray: ...
    @typing.overload
    def solve(self, b: numpy.ndarray) -> numpy.ndarray: ...
    def vectorD(self) -> numpy.ndarray: 
        """
        vectorD( (SimplicialLDLT)self) -> numpy.ndarray :
            Returns the diagonal vector D.

            C++ signature :
                Eigen::Matrix<double, -1, 1, 0, -1, 1> vectorD(Eigen::SimplicialLDLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >)
        """
    pass

class SimplicialLLT(Boost.Python.instance):
    """
    A direct sparse LLT Cholesky factorizations.

    This class provides a LL^T Cholesky factorizations of sparse matrices that are selfadjoint and positive definite.The factorization allows for solving A.X = B where X and B can be either dense or sparse.

    In order to reduce the fill-in, a symmetric permutation P is applied prior to the factorization such that the factorized matrix is P A P^-1.
    """
    @typing.overload
    def __init__(self) -> None: 
        """
        __init__( (object)self) -> None :
            Default constructor

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,Eigen::SparseMatrix<double, 0, int>)
        """
    @typing.overload
    def __init__(self, matrix: csc_matrix) -> None: ...
    def analyzePattern(self, matrix: csc_matrix) -> None: 
        """
        analyzePattern( (SimplicialLLT)self, (csc_matrix)matrix) -> None :
            Performs a symbolic decomposition on the sparcity of matrix.
            This function is particularly useful when solving for several problems having the same structure.

            C++ signature :
                void analyzePattern(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue},Eigen::SparseMatrix<double, 0, int>)
        """
    def cols(self) -> int: 
        """
        cols( (SimplicialLLT)self) -> int :
            Returns the number of columns.

            C++ signature :
                long cols(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def compute(self, matrix: csc_matrix) -> SimplicialLLT: 
        """
        compute( (SimplicialLLT)self, (csc_matrix)matrix) -> SimplicialLLT :
            Computes the sparse Cholesky decomposition of a given matrix.

            C++ signature :
                Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue} compute(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue},Eigen::SparseMatrix<double, 0, int>)
        """
    def determinant(self) -> float: 
        """
        determinant( (SimplicialLLT)self) -> float :
            Returns the determinant of the underlying matrix from the current factorization.

            C++ signature :
                double determinant(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def factorize(self, matrix: csc_matrix) -> None: 
        """
        factorize( (SimplicialLLT)self, (csc_matrix)matrix) -> None :
            Performs a numeric decomposition of a given matrix.
            The given matrix must has the same sparcity than the matrix on which the symbolic decomposition has been performed.
            See also analyzePattern().

            C++ signature :
                void factorize(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue},Eigen::SparseMatrix<double, 0, int>)
        """
    def id(self) -> int: 
        """
        id( (SimplicialLLT)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >)
        """
    def info(self) -> ComputationInfo: 
        """
        info( (SimplicialLLT)self) -> ComputationInfo :
            NumericalIssue if the input contains INF or NaN values or overflow occured. Returns Success otherwise.

            C++ signature :
                Eigen::ComputationInfo info(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def matrixL(self) -> csc_matrix: 
        """
        matrixL( (SimplicialLLT)self) -> csc_matrix :
            Returns the lower triangular matrix L.

            C++ signature :
                Eigen::SparseMatrix<double, 0, int> matrixL(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >)
        """
    def matrixU(self) -> csc_matrix: 
        """
        matrixU( (SimplicialLLT)self) -> csc_matrix :
            Returns the upper triangular matrix U.

            C++ signature :
                Eigen::SparseMatrix<double, 0, int> matrixU(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >)
        """
    def permutationP(self) -> PermutationMatrix: 
        """
        permutationP( (SimplicialLLT)self) -> PermutationMatrix :
            Returns the permutation P.

            C++ signature :
                Eigen::PermutationMatrix<-1, -1, int> permutationP(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def permutationPinv(self) -> PermutationMatrix: 
        """
        permutationPinv( (SimplicialLLT)self) -> PermutationMatrix :
            Returns the inverse P^-1 of the permutation P.

            C++ signature :
                Eigen::PermutationMatrix<-1, -1, int> permutationPinv(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def rows(self) -> int: 
        """
        rows( (SimplicialLLT)self) -> int :
            Returns the number of rows.

            C++ signature :
                long rows(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    def setShift(self, offset_: float, scale: float = 1.0) -> SimplicialLLT: 
        """
        setShift( (SimplicialLLT)self, (float)offset [, (float)scale=1.0]) -> SimplicialLLT :
            Sets the shift parameters that will be used to adjust the diagonal coefficients during the numerical factorization.
            During the numerical factorization, the diagonal coefficients are transformed by the following linear model: d_ii = offset + scale * d_ii.
            The default is the identity transformation with offset=0, and scale=1.

            C++ signature :
                Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue} setShift(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue},double [,double=1.0])
        """
    def size(self) -> int: 
        """
        size( (SimplicialLLT)self) -> int :
            Returns the number of coefficients, which is rows()*cols().

            C++ signature :
                long size(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> > {lvalue})
        """
    @typing.overload
    def solve(self, B: csc_matrix) -> csc_matrix: 
        """
        solve( (SimplicialLLT)self, (numpy.ndarray)b) -> numpy.ndarray :
            Returns the solution x of A x = b using the current decomposition of A.

            C++ signature :
                Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >,Eigen::Matrix<double, -1, 1, 0, -1, 1>)

            C++ signature :
                Eigen::Matrix<double, -1, -1, 0, -1, -1> solve(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >,Eigen::Matrix<double, -1, -1, 0, -1, -1>)

            C++ signature :
                Eigen::SparseMatrix<double, 0, int> solve(Eigen::SimplicialLLT<Eigen::SparseMatrix<double, 0, int>, 1, Eigen::AMDOrdering<int> >,Eigen::SparseMatrix<double, 0, int>)
        """
    @typing.overload
    def solve(self, B: numpy.ndarray) -> numpy.ndarray: ...
    @typing.overload
    def solve(self, b: numpy.ndarray) -> numpy.ndarray: ...
    pass

class StdVec_MatrixXd(Boost.Python.instance):
    @staticmethod
    def __contains__(arg1: StdVec_MatrixXd, arg2: object) -> bool: 
        """
        __contains__( (StdVec_MatrixXd)arg1, (object)arg2) -> bool :

            C++ signature :
                bool __contains__(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > {lvalue},_object*)
        """
    def __copy__(self) -> StdVec_MatrixXd: 
        """
        __copy__( (StdVec_MatrixXd)self) -> StdVec_MatrixXd :
            Returns a copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > __copy__(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >)
        """
    def __deepcopy__(self, memo: dict) -> StdVec_MatrixXd: 
        """
        __deepcopy__( (StdVec_MatrixXd)self, (dict)memo) -> StdVec_MatrixXd :
            Returns a deep copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > __deepcopy__(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >,boost::python::dict)
        """
    @staticmethod
    def __delitem__(arg1: StdVec_MatrixXd, arg2: object) -> None: 
        """
        __delitem__( (StdVec_MatrixXd)arg1, (object)arg2) -> None :

            C++ signature :
                void __delitem__(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > {lvalue},_object*)
        """
    @staticmethod
    def __getinitargs__(arg1: StdVec_MatrixXd) -> tuple: 
        """
        __getinitargs__( (StdVec_MatrixXd)arg1) -> tuple :

            C++ signature :
                boost::python::tuple __getinitargs__(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >)
        """
    @staticmethod
    def __getitem__(arg1: object, arg2: object) -> object: 
        """
        __getitem__( (object)arg1, (object)arg2) -> object :

            C++ signature :
                boost::python::api::object __getitem__(boost::python::back_reference<std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >&>,_object*)

            C++ signature :
                boost::python::api::object __getitem__(boost::python::back_reference<std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >&>,_object*)
        """
    @staticmethod
    def __getstate__(arg1: object) -> tuple: 
        """
        __getstate__( (object)arg1) -> tuple :

            C++ signature :
                boost::python::tuple __getstate__(boost::python::api::object)
        """
    @staticmethod
    @typing.overload
    def __init__(arg1: object) -> None: 
        """
        __init__( (object)arg1) -> None :

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,unsigned long,Eigen::Matrix<double, -1, -1, 0, -1, -1>)

            C++ signature :
                void __init__(_object*,std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >)
        """
    @typing.overload
    def __init__(self, other: StdVec_MatrixXd) -> None: ...
    @typing.overload
    def __init__(self, size: int, value: numpy.ndarray) -> None: ...
    @staticmethod
    def __iter__(arg1: object) -> object: 
        """
        __iter__( (object)arg1) -> object :

            C++ signature :
                boost::python::objects::iterator_range<boost::python::return_internal_reference<1ul, boost::python::default_call_policies>, __gnu_cxx::__normal_iterator<Eigen::Matrix<double, -1, -1, 0, -1, -1>*, std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > > > __iter__(boost::python::back_reference<std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >&>)
        """
    @staticmethod
    def __len__(arg1: StdVec_MatrixXd) -> int: 
        """
        __len__( (StdVec_MatrixXd)arg1) -> int :

            C++ signature :
                unsigned long __len__(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > {lvalue})
        """
    @staticmethod
    def __setitem__(arg1: StdVec_MatrixXd, arg2: object, arg3: object) -> None: 
        """
        __setitem__( (StdVec_MatrixXd)arg1, (object)arg2, (object)arg3) -> None :

            C++ signature :
                void __setitem__(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > {lvalue},_object*,_object*)
        """
    @staticmethod
    def __setstate__(arg1: object, arg2: tuple) -> None: 
        """
        __setstate__( (object)arg1, (tuple)arg2) -> None :

            C++ signature :
                void __setstate__(boost::python::api::object,boost::python::tuple)
        """
    @staticmethod
    def append(arg1: StdVec_MatrixXd, arg2: object) -> None: 
        """
        append( (StdVec_MatrixXd)arg1, (object)arg2) -> None :

            C++ signature :
                void append(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > {lvalue},boost::python::api::object)
        """
    def copy(self) -> StdVec_MatrixXd: 
        """
        copy( (StdVec_MatrixXd)self) -> StdVec_MatrixXd :
            Returns a copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > copy(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >)
        """
    @staticmethod
    def extend(arg1: StdVec_MatrixXd, arg2: object) -> None: 
        """
        extend( (StdVec_MatrixXd)arg1, (object)arg2) -> None :

            C++ signature :
                void extend(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > {lvalue},boost::python::api::object)
        """
    def id(self) -> int: 
        """
        id( (StdVec_MatrixXd)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > >)
        """
    def reserve(self, new_cap: int) -> None: 
        """
        reserve( (StdVec_MatrixXd)self, (int)new_cap) -> None :
            Increase the capacity of the vector to a value that's greater or equal to new_cap.

            C++ signature :
                void reserve(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > {lvalue},unsigned long)
        """
    def tolist(self, deep_copy: bool = False) -> list: 
        """
        tolist( (StdVec_MatrixXd)self [, (bool)deep_copy=False]) -> list :
            Returns the std::vector as a Python list.

            C++ signature :
                boost::python::list tolist(std::vector<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, -1, 0, -1, -1> > > {lvalue} [,bool=False])
        """
    __getstate_manages_dict__ = True
    __instance_size__ = 56
    __safe_for_unpickling__ = True
    pass

class StdVec_MatrixXi(Boost.Python.instance):
    @staticmethod
    def __contains__(arg1: StdVec_MatrixXi, arg2: object) -> bool: 
        """
        __contains__( (StdVec_MatrixXi)arg1, (object)arg2) -> bool :

            C++ signature :
                bool __contains__(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > {lvalue},_object*)
        """
    def __copy__(self) -> StdVec_MatrixXi: 
        """
        __copy__( (StdVec_MatrixXi)self) -> StdVec_MatrixXi :
            Returns a copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > __copy__(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >)
        """
    def __deepcopy__(self, memo: dict) -> StdVec_MatrixXi: 
        """
        __deepcopy__( (StdVec_MatrixXi)self, (dict)memo) -> StdVec_MatrixXi :
            Returns a deep copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > __deepcopy__(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >,boost::python::dict)
        """
    @staticmethod
    def __delitem__(arg1: StdVec_MatrixXi, arg2: object) -> None: 
        """
        __delitem__( (StdVec_MatrixXi)arg1, (object)arg2) -> None :

            C++ signature :
                void __delitem__(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > {lvalue},_object*)
        """
    @staticmethod
    def __getinitargs__(arg1: StdVec_MatrixXi) -> tuple: 
        """
        __getinitargs__( (StdVec_MatrixXi)arg1) -> tuple :

            C++ signature :
                boost::python::tuple __getinitargs__(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >)
        """
    @staticmethod
    def __getitem__(arg1: object, arg2: object) -> object: 
        """
        __getitem__( (object)arg1, (object)arg2) -> object :

            C++ signature :
                boost::python::api::object __getitem__(boost::python::back_reference<std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >&>,_object*)

            C++ signature :
                boost::python::api::object __getitem__(boost::python::back_reference<std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >&>,_object*)
        """
    @staticmethod
    def __getstate__(arg1: object) -> tuple: 
        """
        __getstate__( (object)arg1) -> tuple :

            C++ signature :
                boost::python::tuple __getstate__(boost::python::api::object)
        """
    @staticmethod
    @typing.overload
    def __init__(arg1: object) -> None: 
        """
        __init__( (object)arg1) -> None :

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,unsigned long,Eigen::Matrix<int, -1, -1, 0, -1, -1>)

            C++ signature :
                void __init__(_object*,std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >)
        """
    @typing.overload
    def __init__(self, other: StdVec_MatrixXi) -> None: ...
    @typing.overload
    def __init__(self, size: int, value: numpy.ndarray) -> None: ...
    @staticmethod
    def __iter__(arg1: object) -> object: 
        """
        __iter__( (object)arg1) -> object :

            C++ signature :
                boost::python::objects::iterator_range<boost::python::return_internal_reference<1ul, boost::python::default_call_policies>, __gnu_cxx::__normal_iterator<Eigen::Matrix<int, -1, -1, 0, -1, -1>*, std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > > > __iter__(boost::python::back_reference<std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >&>)
        """
    @staticmethod
    def __len__(arg1: StdVec_MatrixXi) -> int: 
        """
        __len__( (StdVec_MatrixXi)arg1) -> int :

            C++ signature :
                unsigned long __len__(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > {lvalue})
        """
    @staticmethod
    def __setitem__(arg1: StdVec_MatrixXi, arg2: object, arg3: object) -> None: 
        """
        __setitem__( (StdVec_MatrixXi)arg1, (object)arg2, (object)arg3) -> None :

            C++ signature :
                void __setitem__(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > {lvalue},_object*,_object*)
        """
    @staticmethod
    def __setstate__(arg1: object, arg2: tuple) -> None: 
        """
        __setstate__( (object)arg1, (tuple)arg2) -> None :

            C++ signature :
                void __setstate__(boost::python::api::object,boost::python::tuple)
        """
    @staticmethod
    def append(arg1: StdVec_MatrixXi, arg2: object) -> None: 
        """
        append( (StdVec_MatrixXi)arg1, (object)arg2) -> None :

            C++ signature :
                void append(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > {lvalue},boost::python::api::object)
        """
    def copy(self) -> StdVec_MatrixXi: 
        """
        copy( (StdVec_MatrixXi)self) -> StdVec_MatrixXi :
            Returns a copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > copy(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >)
        """
    @staticmethod
    def extend(arg1: StdVec_MatrixXi, arg2: object) -> None: 
        """
        extend( (StdVec_MatrixXi)arg1, (object)arg2) -> None :

            C++ signature :
                void extend(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > {lvalue},boost::python::api::object)
        """
    def id(self) -> int: 
        """
        id( (StdVec_MatrixXi)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > >)
        """
    def reserve(self, new_cap: int) -> None: 
        """
        reserve( (StdVec_MatrixXi)self, (int)new_cap) -> None :
            Increase the capacity of the vector to a value that's greater or equal to new_cap.

            C++ signature :
                void reserve(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > {lvalue},unsigned long)
        """
    def tolist(self, deep_copy: bool = False) -> list: 
        """
        tolist( (StdVec_MatrixXi)self [, (bool)deep_copy=False]) -> list :
            Returns the std::vector as a Python list.

            C++ signature :
                boost::python::list tolist(std::vector<Eigen::Matrix<int, -1, -1, 0, -1, -1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, -1, 0, -1, -1> > > {lvalue} [,bool=False])
        """
    __getstate_manages_dict__ = True
    __instance_size__ = 56
    __safe_for_unpickling__ = True
    pass

class StdVec_VectorXd(Boost.Python.instance):
    @staticmethod
    def __contains__(arg1: StdVec_VectorXd, arg2: object) -> bool: 
        """
        __contains__( (StdVec_VectorXd)arg1, (object)arg2) -> bool :

            C++ signature :
                bool __contains__(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > {lvalue},_object*)
        """
    def __copy__(self) -> StdVec_VectorXd: 
        """
        __copy__( (StdVec_VectorXd)self) -> StdVec_VectorXd :
            Returns a copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > __copy__(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >)
        """
    def __deepcopy__(self, memo: dict) -> StdVec_VectorXd: 
        """
        __deepcopy__( (StdVec_VectorXd)self, (dict)memo) -> StdVec_VectorXd :
            Returns a deep copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > __deepcopy__(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >,boost::python::dict)
        """
    @staticmethod
    def __delitem__(arg1: StdVec_VectorXd, arg2: object) -> None: 
        """
        __delitem__( (StdVec_VectorXd)arg1, (object)arg2) -> None :

            C++ signature :
                void __delitem__(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > {lvalue},_object*)
        """
    @staticmethod
    def __getinitargs__(arg1: StdVec_VectorXd) -> tuple: 
        """
        __getinitargs__( (StdVec_VectorXd)arg1) -> tuple :

            C++ signature :
                boost::python::tuple __getinitargs__(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >)
        """
    @staticmethod
    def __getitem__(arg1: object, arg2: object) -> object: 
        """
        __getitem__( (object)arg1, (object)arg2) -> object :

            C++ signature :
                boost::python::api::object __getitem__(boost::python::back_reference<std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >&>,_object*)

            C++ signature :
                boost::python::api::object __getitem__(boost::python::back_reference<std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >&>,_object*)
        """
    @staticmethod
    def __getstate__(arg1: object) -> tuple: 
        """
        __getstate__( (object)arg1) -> tuple :

            C++ signature :
                boost::python::tuple __getstate__(boost::python::api::object)
        """
    @staticmethod
    @typing.overload
    def __init__(arg1: object) -> None: 
        """
        __init__( (object)arg1) -> None :

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,unsigned long,Eigen::Matrix<double, -1, 1, 0, -1, 1>)

            C++ signature :
                void __init__(_object*,std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >)
        """
    @typing.overload
    def __init__(self, other: StdVec_VectorXd) -> None: ...
    @typing.overload
    def __init__(self, size: int, value: numpy.ndarray) -> None: ...
    @staticmethod
    def __iter__(arg1: object) -> object: 
        """
        __iter__( (object)arg1) -> object :

            C++ signature :
                boost::python::objects::iterator_range<boost::python::return_internal_reference<1ul, boost::python::default_call_policies>, __gnu_cxx::__normal_iterator<Eigen::Matrix<double, -1, 1, 0, -1, 1>*, std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > > > __iter__(boost::python::back_reference<std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >&>)
        """
    @staticmethod
    def __len__(arg1: StdVec_VectorXd) -> int: 
        """
        __len__( (StdVec_VectorXd)arg1) -> int :

            C++ signature :
                unsigned long __len__(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > {lvalue})
        """
    @staticmethod
    def __setitem__(arg1: StdVec_VectorXd, arg2: object, arg3: object) -> None: 
        """
        __setitem__( (StdVec_VectorXd)arg1, (object)arg2, (object)arg3) -> None :

            C++ signature :
                void __setitem__(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > {lvalue},_object*,_object*)
        """
    @staticmethod
    def __setstate__(arg1: object, arg2: tuple) -> None: 
        """
        __setstate__( (object)arg1, (tuple)arg2) -> None :

            C++ signature :
                void __setstate__(boost::python::api::object,boost::python::tuple)
        """
    @staticmethod
    def append(arg1: StdVec_VectorXd, arg2: object) -> None: 
        """
        append( (StdVec_VectorXd)arg1, (object)arg2) -> None :

            C++ signature :
                void append(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > {lvalue},boost::python::api::object)
        """
    def copy(self) -> StdVec_VectorXd: 
        """
        copy( (StdVec_VectorXd)self) -> StdVec_VectorXd :
            Returns a copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > copy(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >)
        """
    @staticmethod
    def extend(arg1: StdVec_VectorXd, arg2: object) -> None: 
        """
        extend( (StdVec_VectorXd)arg1, (object)arg2) -> None :

            C++ signature :
                void extend(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > {lvalue},boost::python::api::object)
        """
    def id(self) -> int: 
        """
        id( (StdVec_VectorXd)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > >)
        """
    def reserve(self, new_cap: int) -> None: 
        """
        reserve( (StdVec_VectorXd)self, (int)new_cap) -> None :
            Increase the capacity of the vector to a value that's greater or equal to new_cap.

            C++ signature :
                void reserve(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > {lvalue},unsigned long)
        """
    def tolist(self, deep_copy: bool = False) -> list: 
        """
        tolist( (StdVec_VectorXd)self [, (bool)deep_copy=False]) -> list :
            Returns the std::vector as a Python list.

            C++ signature :
                boost::python::list tolist(std::vector<Eigen::Matrix<double, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<double, -1, 1, 0, -1, 1> > > {lvalue} [,bool=False])
        """
    __getstate_manages_dict__ = True
    __instance_size__ = 56
    __safe_for_unpickling__ = True
    pass

class StdVec_VectorXi(Boost.Python.instance):
    @staticmethod
    def __contains__(arg1: StdVec_VectorXi, arg2: object) -> bool: 
        """
        __contains__( (StdVec_VectorXi)arg1, (object)arg2) -> bool :

            C++ signature :
                bool __contains__(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > {lvalue},_object*)
        """
    def __copy__(self) -> StdVec_VectorXi: 
        """
        __copy__( (StdVec_VectorXi)self) -> StdVec_VectorXi :
            Returns a copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > __copy__(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >)
        """
    def __deepcopy__(self, memo: dict) -> StdVec_VectorXi: 
        """
        __deepcopy__( (StdVec_VectorXi)self, (dict)memo) -> StdVec_VectorXi :
            Returns a deep copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > __deepcopy__(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >,boost::python::dict)
        """
    @staticmethod
    def __delitem__(arg1: StdVec_VectorXi, arg2: object) -> None: 
        """
        __delitem__( (StdVec_VectorXi)arg1, (object)arg2) -> None :

            C++ signature :
                void __delitem__(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > {lvalue},_object*)
        """
    @staticmethod
    def __getinitargs__(arg1: StdVec_VectorXi) -> tuple: 
        """
        __getinitargs__( (StdVec_VectorXi)arg1) -> tuple :

            C++ signature :
                boost::python::tuple __getinitargs__(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >)
        """
    @staticmethod
    def __getitem__(arg1: object, arg2: object) -> object: 
        """
        __getitem__( (object)arg1, (object)arg2) -> object :

            C++ signature :
                boost::python::api::object __getitem__(boost::python::back_reference<std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >&>,_object*)

            C++ signature :
                boost::python::api::object __getitem__(boost::python::back_reference<std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >&>,_object*)
        """
    @staticmethod
    def __getstate__(arg1: object) -> tuple: 
        """
        __getstate__( (object)arg1) -> tuple :

            C++ signature :
                boost::python::tuple __getstate__(boost::python::api::object)
        """
    @staticmethod
    @typing.overload
    def __init__(arg1: object) -> None: 
        """
        __init__( (object)arg1) -> None :

            C++ signature :
                void __init__(_object*)

            C++ signature :
                void __init__(_object*,unsigned long,Eigen::Matrix<int, -1, 1, 0, -1, 1>)

            C++ signature :
                void __init__(_object*,std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >)
        """
    @typing.overload
    def __init__(self, other: StdVec_VectorXi) -> None: ...
    @typing.overload
    def __init__(self, size: int, value: numpy.ndarray) -> None: ...
    @staticmethod
    def __iter__(arg1: object) -> object: 
        """
        __iter__( (object)arg1) -> object :

            C++ signature :
                boost::python::objects::iterator_range<boost::python::return_internal_reference<1ul, boost::python::default_call_policies>, __gnu_cxx::__normal_iterator<Eigen::Matrix<int, -1, 1, 0, -1, 1>*, std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > > > __iter__(boost::python::back_reference<std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >&>)
        """
    @staticmethod
    def __len__(arg1: StdVec_VectorXi) -> int: 
        """
        __len__( (StdVec_VectorXi)arg1) -> int :

            C++ signature :
                unsigned long __len__(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > {lvalue})
        """
    @staticmethod
    def __setitem__(arg1: StdVec_VectorXi, arg2: object, arg3: object) -> None: 
        """
        __setitem__( (StdVec_VectorXi)arg1, (object)arg2, (object)arg3) -> None :

            C++ signature :
                void __setitem__(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > {lvalue},_object*,_object*)
        """
    @staticmethod
    def __setstate__(arg1: object, arg2: tuple) -> None: 
        """
        __setstate__( (object)arg1, (tuple)arg2) -> None :

            C++ signature :
                void __setstate__(boost::python::api::object,boost::python::tuple)
        """
    @staticmethod
    def append(arg1: StdVec_VectorXi, arg2: object) -> None: 
        """
        append( (StdVec_VectorXi)arg1, (object)arg2) -> None :

            C++ signature :
                void append(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > {lvalue},boost::python::api::object)
        """
    def copy(self) -> StdVec_VectorXi: 
        """
        copy( (StdVec_VectorXi)self) -> StdVec_VectorXi :
            Returns a copy of *this.

            C++ signature :
                std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > copy(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >)
        """
    @staticmethod
    def extend(arg1: StdVec_VectorXi, arg2: object) -> None: 
        """
        extend( (StdVec_VectorXi)arg1, (object)arg2) -> None :

            C++ signature :
                void extend(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > {lvalue},boost::python::api::object)
        """
    def id(self) -> int: 
        """
        id( (StdVec_VectorXi)self) -> int :
            Returns the unique identity of an object.
            For object held in C++, it corresponds to its memory address.

            C++ signature :
                long id(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > >)
        """
    def reserve(self, new_cap: int) -> None: 
        """
        reserve( (StdVec_VectorXi)self, (int)new_cap) -> None :
            Increase the capacity of the vector to a value that's greater or equal to new_cap.

            C++ signature :
                void reserve(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > {lvalue},unsigned long)
        """
    def tolist(self, deep_copy: bool = False) -> list: 
        """
        tolist( (StdVec_VectorXi)self [, (bool)deep_copy=False]) -> list :
            Returns the std::vector as a Python list.

            C++ signature :
                boost::python::list tolist(std::vector<Eigen::Matrix<int, -1, 1, 0, -1, 1>, Eigen::aligned_allocator<Eigen::Matrix<int, -1, 1, 0, -1, 1> > > {lvalue} [,bool=False])
        """
    __getstate_manages_dict__ = True
    __instance_size__ = 56
    __safe_for_unpickling__ = True
    pass

class solvers(Boost.Python.instance):
    class ComputationInfo(Boost.Python.enum, int):
        InvalidInput = eigenpy.eigenpy_pywrap.ComputationInfo.InvalidInput
        NoConvergence = eigenpy.eigenpy_pywrap.ComputationInfo.NoConvergence
        NumericalIssue = eigenpy.eigenpy_pywrap.ComputationInfo.NumericalIssue
        Success = eigenpy.eigenpy_pywrap.ComputationInfo.Success
        __slots__ = ()
        names = {'Success': eigenpy.eigenpy_pywrap.ComputationInfo.Success, 'NumericalIssue': eigenpy.eigenpy_pywrap.ComputationInfo.NumericalIssue, 'NoConvergence': eigenpy.eigenpy_pywrap.ComputationInfo.NoConvergence, 'InvalidInput': eigenpy.eigenpy_pywrap.ComputationInfo.InvalidInput}
        values = {0: eigenpy.eigenpy_pywrap.ComputationInfo.Success, 1: eigenpy.eigenpy_pywrap.ComputationInfo.NumericalIssue, 2: eigenpy.eigenpy_pywrap.ComputationInfo.NoConvergence, 3: eigenpy.eigenpy_pywrap.ComputationInfo.InvalidInput}
        pass
    class ConjugateGradient(Boost.Python.instance):
        @staticmethod
        @typing.overload
        def __init__(arg1: object) -> None: 
            """
            __init__( (object)arg1) -> None :
                Default constructor

                C++ signature :
                    void __init__(_object*)

                C++ signature :
                    void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        @typing.overload
        def __init__(arg1: object, A: numpy.ndarray) -> None: ...
        @staticmethod
        def analyzePattern(arg1: ConjugateGradient, A: numpy.ndarray) -> ConjugateGradient: 
            """
            analyzePattern( (ConjugateGradient)arg1, (numpy.ndarray)A) -> ConjugateGradient :
                Initializes the iterative solver for the sparsity pattern of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls analyzePattern on the preconditioner.
                In the future we might, for instance, implement column reordering for faster matrix vector products.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue} analyzePattern(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        def compute(arg1: ConjugateGradient, A: numpy.ndarray) -> ConjugateGradient: 
            """
            compute( (ConjugateGradient)arg1, (numpy.ndarray)A) -> ConjugateGradient :
                Initializes the iterative solver with the numerical values of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls factorize on the preconditioner.
                In the future we might, for instance, implement column reordering for faster matrix vector products.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue} compute(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        def error(arg1: ConjugateGradient) -> float: 
            """
            error( (ConjugateGradient)arg1) -> float :
                Returns the tolerance error reached during the last solve.
                It is a close approximation of the true relative residual error |Ax-b|/|b|.

                C++ signature :
                    double error(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def factorize(arg1: ConjugateGradient, A: numpy.ndarray) -> ConjugateGradient: 
            """
            factorize( (ConjugateGradient)arg1, (numpy.ndarray)A) -> ConjugateGradient :
                Initializes the iterative solver with the numerical values of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls factorize on the preconditioner.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue} factorize(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        def id(self) -> int: 
            """
            id( (ConjugateGradient)self) -> int :
                Returns the unique identity of an object.
                For object held in C++, it corresponds to its memory address.

                C++ signature :
                    long id(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> >)
            """
        @staticmethod
        def info(arg1: ConjugateGradient) -> ComputationInfo: 
            """
            info( (ConjugateGradient)arg1) -> ComputationInfo :
                Returns success if the iterations converged, and NoConvergence otherwise.

                C++ signature :
                    Eigen::ComputationInfo info(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def iterations(arg1: ConjugateGradient) -> int: 
            """
            iterations( (ConjugateGradient)arg1) -> int :
                Returns the number of iterations performed during the last solve.

                C++ signature :
                    long iterations(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def maxIterations(arg1: ConjugateGradient) -> int: 
            """
            maxIterations( (ConjugateGradient)arg1) -> int :
                Returns the max number of iterations.
                It is either the value setted by setMaxIterations or, by default, twice the number of columns of the matrix.

                C++ signature :
                    long maxIterations(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def preconditioner(arg1: ConjugateGradient) -> DiagonalPreconditioner: 
            """
            preconditioner( (ConjugateGradient)arg1) -> DiagonalPreconditioner :
                Returns a read-write reference to the preconditioner for custom configuration.

                C++ signature :
                    Eigen::DiagonalPreconditioner<double> {lvalue} preconditioner(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def setMaxIterations(arg1: ConjugateGradient, arg2: int) -> ConjugateGradient: 
            """
            setMaxIterations( (ConjugateGradient)arg1, (int)arg2) -> ConjugateGradient :
                Sets the max number of iterations.
                Default is twice the number of columns of the matrix.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue} setMaxIterations(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue},long)
            """
        @staticmethod
        def setTolerance(arg1: ConjugateGradient, arg2: float) -> ConjugateGradient: 
            """
            setTolerance( (ConjugateGradient)arg1, (float)arg2) -> ConjugateGradient :
                Sets the tolerance threshold used by the stopping criteria.
                This value is used as an upper bound to the relative residual error: |Ax-b|/|b|. The default value is the machine precision.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue} setTolerance(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue},double)
            """
        @staticmethod
        def solve(arg1: ConjugateGradient, b: numpy.ndarray) -> numpy.ndarray: 
            """
            solve( (ConjugateGradient)arg1, (numpy.ndarray)b) -> numpy.ndarray :
                Returns the solution x of Ax = b using the current decomposition of A.

                C++ signature :
                    Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>)
            """
        @staticmethod
        def solveWithGuess(arg1: ConjugateGradient, b: numpy.ndarray, x0: numpy.ndarray) -> numpy.ndarray: 
            """
            solveWithGuess( (ConjugateGradient)arg1, (numpy.ndarray)b, (numpy.ndarray)x0) -> numpy.ndarray :
                Returns the solution x of Ax = b using the current decomposition of A and x0 as an initial solution.

                C++ signature :
                    Eigen::Matrix<double, -1, 1, 0, -1, 1> solveWithGuess(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>,Eigen::Matrix<double, -1, 1, 0, -1, 1>)
            """
        @staticmethod
        def tolerance(arg1: ConjugateGradient) -> float: 
            """
            tolerance( (ConjugateGradient)arg1) -> float :
                Returns he tolerance threshold used by the stopping criteria.

                C++ signature :
                    double tolerance(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::DiagonalPreconditioner<double> > {lvalue})
            """
        pass
    class DiagonalPreconditioner(Boost.Python.instance):
        """
        A preconditioner based on the digonal entrie.
        This class allows to approximately solve for A.x = b problems assuming A is a diagonal matrix.
        """
        def id(self) -> int: 
            """
            id( (DiagonalPreconditioner)self) -> int :
                Returns the unique identity of an object.
                For object held in C++, it corresponds to its memory address.

                C++ signature :
                    long id(Eigen::DiagonalPreconditioner<double>)
            """
        pass
    class IdentityConjugateGradient(Boost.Python.instance):
        @staticmethod
        @typing.overload
        def __init__(arg1: object) -> None: 
            """
            __init__( (object)arg1) -> None :
                Default constructor

                C++ signature :
                    void __init__(_object*)

                C++ signature :
                    void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        @typing.overload
        def __init__(arg1: object, A: numpy.ndarray) -> None: ...
        @staticmethod
        def analyzePattern(arg1: IdentityConjugateGradient, A: numpy.ndarray) -> IdentityConjugateGradient: 
            """
            analyzePattern( (IdentityConjugateGradient)arg1, (numpy.ndarray)A) -> IdentityConjugateGradient :
                Initializes the iterative solver for the sparsity pattern of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls analyzePattern on the preconditioner.
                In the future we might, for instance, implement column reordering for faster matrix vector products.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue} analyzePattern(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        def compute(arg1: IdentityConjugateGradient, A: numpy.ndarray) -> IdentityConjugateGradient: 
            """
            compute( (IdentityConjugateGradient)arg1, (numpy.ndarray)A) -> IdentityConjugateGradient :
                Initializes the iterative solver with the numerical values of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls factorize on the preconditioner.
                In the future we might, for instance, implement column reordering for faster matrix vector products.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue} compute(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        def error(arg1: IdentityConjugateGradient) -> float: 
            """
            error( (IdentityConjugateGradient)arg1) -> float :
                Returns the tolerance error reached during the last solve.
                It is a close approximation of the true relative residual error |Ax-b|/|b|.

                C++ signature :
                    double error(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue})
            """
        @staticmethod
        def factorize(arg1: IdentityConjugateGradient, A: numpy.ndarray) -> IdentityConjugateGradient: 
            """
            factorize( (IdentityConjugateGradient)arg1, (numpy.ndarray)A) -> IdentityConjugateGradient :
                Initializes the iterative solver with the numerical values of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls factorize on the preconditioner.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue} factorize(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        def id(self) -> int: 
            """
            id( (IdentityConjugateGradient)self) -> int :
                Returns the unique identity of an object.
                For object held in C++, it corresponds to its memory address.

                C++ signature :
                    long id(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner>)
            """
        @staticmethod
        def info(arg1: IdentityConjugateGradient) -> ComputationInfo: 
            """
            info( (IdentityConjugateGradient)arg1) -> ComputationInfo :
                Returns success if the iterations converged, and NoConvergence otherwise.

                C++ signature :
                    Eigen::ComputationInfo info(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue})
            """
        @staticmethod
        def iterations(arg1: IdentityConjugateGradient) -> int: 
            """
            iterations( (IdentityConjugateGradient)arg1) -> int :
                Returns the number of iterations performed during the last solve.

                C++ signature :
                    long iterations(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue})
            """
        @staticmethod
        def maxIterations(arg1: IdentityConjugateGradient) -> int: 
            """
            maxIterations( (IdentityConjugateGradient)arg1) -> int :
                Returns the max number of iterations.
                It is either the value setted by setMaxIterations or, by default, twice the number of columns of the matrix.

                C++ signature :
                    long maxIterations(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue})
            """
        @staticmethod
        def preconditioner(arg1: IdentityConjugateGradient) -> IdentityPreconditioner: 
            """
            preconditioner( (IdentityConjugateGradient)arg1) -> IdentityPreconditioner :
                Returns a read-write reference to the preconditioner for custom configuration.

                C++ signature :
                    Eigen::IdentityPreconditioner {lvalue} preconditioner(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue})
            """
        @staticmethod
        def setMaxIterations(arg1: IdentityConjugateGradient, arg2: int) -> IdentityConjugateGradient: 
            """
            setMaxIterations( (IdentityConjugateGradient)arg1, (int)arg2) -> IdentityConjugateGradient :
                Sets the max number of iterations.
                Default is twice the number of columns of the matrix.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue} setMaxIterations(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue},long)
            """
        @staticmethod
        def setTolerance(arg1: IdentityConjugateGradient, arg2: float) -> IdentityConjugateGradient: 
            """
            setTolerance( (IdentityConjugateGradient)arg1, (float)arg2) -> IdentityConjugateGradient :
                Sets the tolerance threshold used by the stopping criteria.
                This value is used as an upper bound to the relative residual error: |Ax-b|/|b|. The default value is the machine precision.

                C++ signature :
                    Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue} setTolerance(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue},double)
            """
        @staticmethod
        def solve(arg1: IdentityConjugateGradient, b: numpy.ndarray) -> numpy.ndarray: 
            """
            solve( (IdentityConjugateGradient)arg1, (numpy.ndarray)b) -> numpy.ndarray :
                Returns the solution x of Ax = b using the current decomposition of A.

                C++ signature :
                    Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>)
            """
        @staticmethod
        def solveWithGuess(arg1: IdentityConjugateGradient, b: numpy.ndarray, x0: numpy.ndarray) -> numpy.ndarray: 
            """
            solveWithGuess( (IdentityConjugateGradient)arg1, (numpy.ndarray)b, (numpy.ndarray)x0) -> numpy.ndarray :
                Returns the solution x of Ax = b using the current decomposition of A and x0 as an initial solution.

                C++ signature :
                    Eigen::Matrix<double, -1, 1, 0, -1, 1> solveWithGuess(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>,Eigen::Matrix<double, -1, 1, 0, -1, 1>)
            """
        @staticmethod
        def tolerance(arg1: IdentityConjugateGradient) -> float: 
            """
            tolerance( (IdentityConjugateGradient)arg1) -> float :
                Returns he tolerance threshold used by the stopping criteria.

                C++ signature :
                    double tolerance(Eigen::ConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, 3, Eigen::IdentityPreconditioner> {lvalue})
            """
        pass
    class IdentityPreconditioner(Boost.Python.instance):
        @staticmethod
        @typing.overload
        def __init__(arg1: object) -> None: 
            """
            __init__( (object)arg1) -> None :
                Default constructor

                C++ signature :
                    void __init__(_object*)

                C++ signature :
                    void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @typing.overload
        def __init__(self, A: numpy.ndarray) -> None: ...
        @staticmethod
        def compute(arg1: IdentityPreconditioner, mat: numpy.ndarray) -> IdentityPreconditioner: 
            """
            compute( (IdentityPreconditioner)arg1, (numpy.ndarray)mat) -> IdentityPreconditioner :
                Initialize the preconditioner from the matrix value.

                C++ signature :
                    Eigen::IdentityPreconditioner {lvalue} compute(Eigen::IdentityPreconditioner {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        def factorize(arg1: IdentityPreconditioner, mat: numpy.ndarray) -> IdentityPreconditioner: 
            """
            factorize( (IdentityPreconditioner)arg1, (numpy.ndarray)mat) -> IdentityPreconditioner :
                Initialize the preconditioner from the matrix value, i.e factorize the mat given as input to approximate its inverse.

                C++ signature :
                    Eigen::IdentityPreconditioner {lvalue} factorize(Eigen::IdentityPreconditioner {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        def id(self) -> int: 
            """
            id( (IdentityPreconditioner)self) -> int :
                Returns the unique identity of an object.
                For object held in C++, it corresponds to its memory address.

                C++ signature :
                    long id(Eigen::IdentityPreconditioner)
            """
        @staticmethod
        def info(arg1: IdentityPreconditioner) -> ComputationInfo: 
            """
            info( (IdentityPreconditioner)arg1) -> ComputationInfo :
                Returns success if the Preconditioner has been well initialized.

                C++ signature :
                    Eigen::ComputationInfo info(Eigen::IdentityPreconditioner {lvalue})
            """
        @staticmethod
        def solve(arg1: IdentityPreconditioner, b: numpy.ndarray) -> numpy.ndarray: 
            """
            solve( (IdentityPreconditioner)arg1, (numpy.ndarray)b) -> numpy.ndarray :
                Returns the solution A * z = b where the preconditioner is an estimate of A^-1.

                C++ signature :
                    Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::IdentityPreconditioner {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>)
            """
        pass
    class LeastSquareDiagonalPreconditioner(Boost.Python.instance):
        """
        Jacobi preconditioner for LeastSquaresConjugateGradient.
        his class allows to approximately solve for A' A x  = A' b problems assuming A' A is a diagonal matrix.
        """
        @staticmethod
        @typing.overload
        def __init__(arg1: object) -> None: 
            """
            __init__( (object)arg1) -> None :
                Default constructor

                C++ signature :
                    void __init__(_object*)

                C++ signature :
                    void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @typing.overload
        def __init__(self, A: numpy.ndarray) -> None: ...
        @staticmethod
        def compute(arg1: LeastSquareDiagonalPreconditioner, mat: numpy.ndarray) -> DiagonalPreconditioner: 
            """
            compute( (LeastSquareDiagonalPreconditioner)arg1, (numpy.ndarray)mat) -> DiagonalPreconditioner :
                Initialize the preconditioner from the matrix value.

                C++ signature :
                    Eigen::DiagonalPreconditioner<double> {lvalue} compute(Eigen::LeastSquareDiagonalPreconditioner<double> {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        def factorize(arg1: LeastSquareDiagonalPreconditioner, mat: numpy.ndarray) -> DiagonalPreconditioner: 
            """
            factorize( (LeastSquareDiagonalPreconditioner)arg1, (numpy.ndarray)mat) -> DiagonalPreconditioner :
                Initialize the preconditioner from the matrix value, i.e factorize the mat given as input to approximate its inverse.

                C++ signature :
                    Eigen::DiagonalPreconditioner<double> {lvalue} factorize(Eigen::LeastSquareDiagonalPreconditioner<double> {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        def id(self) -> int: 
            """
            id( (LeastSquareDiagonalPreconditioner)self) -> int :
                Returns the unique identity of an object.
                For object held in C++, it corresponds to its memory address.

                C++ signature :
                    long id(Eigen::LeastSquareDiagonalPreconditioner<double>)
            """
        @staticmethod
        def info(arg1: LeastSquareDiagonalPreconditioner) -> ComputationInfo: 
            """
            info( (LeastSquareDiagonalPreconditioner)arg1) -> ComputationInfo :
                Returns success if the Preconditioner has been well initialized.

                C++ signature :
                    Eigen::ComputationInfo info(Eigen::LeastSquareDiagonalPreconditioner<double> {lvalue})
            """
        @staticmethod
        def solve(arg1: DiagonalPreconditioner, b: numpy.ndarray) -> numpy.ndarray: 
            """
            solve( (DiagonalPreconditioner)arg1, (numpy.ndarray)b) -> numpy.ndarray :
                Returns the solution A * z = b where the preconditioner is an estimate of A^-1.

                C++ signature :
                    Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::DiagonalPreconditioner<double> {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>)
            """
        pass
    class LeastSquaresConjugateGradient(Boost.Python.instance):
        @staticmethod
        @typing.overload
        def __init__(arg1: object) -> None: 
            """
            __init__( (object)arg1) -> None :
                Default constructor

                C++ signature :
                    void __init__(_object*)

                C++ signature :
                    void __init__(_object*,Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        @typing.overload
        def __init__(arg1: object, A: numpy.ndarray) -> None: ...
        @staticmethod
        def analyzePattern(arg1: LeastSquaresConjugateGradient, A: numpy.ndarray) -> LeastSquaresConjugateGradient: 
            """
            analyzePattern( (LeastSquaresConjugateGradient)arg1, (numpy.ndarray)A) -> LeastSquaresConjugateGradient :
                Initializes the iterative solver for the sparsity pattern of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls analyzePattern on the preconditioner.
                In the future we might, for instance, implement column reordering for faster matrix vector products.

                C++ signature :
                    Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue} analyzePattern(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        def compute(arg1: LeastSquaresConjugateGradient, A: numpy.ndarray) -> LeastSquaresConjugateGradient: 
            """
            compute( (LeastSquaresConjugateGradient)arg1, (numpy.ndarray)A) -> LeastSquaresConjugateGradient :
                Initializes the iterative solver with the numerical values of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls factorize on the preconditioner.
                In the future we might, for instance, implement column reordering for faster matrix vector products.

                C++ signature :
                    Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue} compute(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        @staticmethod
        def error(arg1: LeastSquaresConjugateGradient) -> float: 
            """
            error( (LeastSquaresConjugateGradient)arg1) -> float :
                Returns the tolerance error reached during the last solve.
                It is a close approximation of the true relative residual error |Ax-b|/|b|.

                C++ signature :
                    double error(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def factorize(arg1: LeastSquaresConjugateGradient, A: numpy.ndarray) -> LeastSquaresConjugateGradient: 
            """
            factorize( (LeastSquaresConjugateGradient)arg1, (numpy.ndarray)A) -> LeastSquaresConjugateGradient :
                Initializes the iterative solver with the numerical values of the matrix A for further solving Ax=b problems.
                Currently, this function mostly calls factorize on the preconditioner.

                C++ signature :
                    Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue} factorize(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, -1, 0, -1, -1>)
            """
        def id(self) -> int: 
            """
            id( (LeastSquaresConjugateGradient)self) -> int :
                Returns the unique identity of an object.
                For object held in C++, it corresponds to its memory address.

                C++ signature :
                    long id(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> >)
            """
        @staticmethod
        def info(arg1: LeastSquaresConjugateGradient) -> ComputationInfo: 
            """
            info( (LeastSquaresConjugateGradient)arg1) -> ComputationInfo :
                Returns success if the iterations converged, and NoConvergence otherwise.

                C++ signature :
                    Eigen::ComputationInfo info(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def iterations(arg1: LeastSquaresConjugateGradient) -> int: 
            """
            iterations( (LeastSquaresConjugateGradient)arg1) -> int :
                Returns the number of iterations performed during the last solve.

                C++ signature :
                    long iterations(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def maxIterations(arg1: LeastSquaresConjugateGradient) -> int: 
            """
            maxIterations( (LeastSquaresConjugateGradient)arg1) -> int :
                Returns the max number of iterations.
                It is either the value setted by setMaxIterations or, by default, twice the number of columns of the matrix.

                C++ signature :
                    long maxIterations(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def preconditioner(arg1: LeastSquaresConjugateGradient) -> LeastSquareDiagonalPreconditioner: 
            """
            preconditioner( (LeastSquaresConjugateGradient)arg1) -> LeastSquareDiagonalPreconditioner :
                Returns a read-write reference to the preconditioner for custom configuration.

                C++ signature :
                    Eigen::LeastSquareDiagonalPreconditioner<double> {lvalue} preconditioner(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue})
            """
        @staticmethod
        def setMaxIterations(arg1: LeastSquaresConjugateGradient, arg2: int) -> LeastSquaresConjugateGradient: 
            """
            setMaxIterations( (LeastSquaresConjugateGradient)arg1, (int)arg2) -> LeastSquaresConjugateGradient :
                Sets the max number of iterations.
                Default is twice the number of columns of the matrix.

                C++ signature :
                    Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue} setMaxIterations(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue},long)
            """
        @staticmethod
        def setTolerance(arg1: LeastSquaresConjugateGradient, arg2: float) -> LeastSquaresConjugateGradient: 
            """
            setTolerance( (LeastSquaresConjugateGradient)arg1, (float)arg2) -> LeastSquaresConjugateGradient :
                Sets the tolerance threshold used by the stopping criteria.
                This value is used as an upper bound to the relative residual error: |Ax-b|/|b|. The default value is the machine precision.

                C++ signature :
                    Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue} setTolerance(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue},double)
            """
        @staticmethod
        def solve(arg1: LeastSquaresConjugateGradient, b: numpy.ndarray) -> numpy.ndarray: 
            """
            solve( (LeastSquaresConjugateGradient)arg1, (numpy.ndarray)b) -> numpy.ndarray :
                Returns the solution x of Ax = b using the current decomposition of A.

                C++ signature :
                    Eigen::Matrix<double, -1, 1, 0, -1, 1> solve(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>)
            """
        @staticmethod
        def solveWithGuess(arg1: LeastSquaresConjugateGradient, b: numpy.ndarray, x0: numpy.ndarray) -> numpy.ndarray: 
            """
            solveWithGuess( (LeastSquaresConjugateGradient)arg1, (numpy.ndarray)b, (numpy.ndarray)x0) -> numpy.ndarray :
                Returns the solution x of Ax = b using the current decomposition of A and x0 as an initial solution.

                C++ signature :
                    Eigen::Matrix<double, -1, 1, 0, -1, 1> solveWithGuess(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue},Eigen::Matrix<double, -1, 1, 0, -1, 1>,Eigen::Matrix<double, -1, 1, 0, -1, 1>)
            """
        @staticmethod
        def tolerance(arg1: LeastSquaresConjugateGradient) -> float: 
            """
            tolerance( (LeastSquaresConjugateGradient)arg1) -> float :
                Returns he tolerance threshold used by the stopping criteria.

                C++ signature :
                    double tolerance(Eigen::LeastSquaresConjugateGradient<Eigen::Matrix<double, -1, -1, 0, -1, -1>, Eigen::LeastSquareDiagonalPreconditioner<double> > {lvalue})
            """
        pass
    @staticmethod
    def __init__(arg1: object) -> None: 
        """
        __init__( (object)arg1) -> None :

            C++ signature :
                void __init__(_object*)
        """
    __instance_size__ = 40
    pass

def SimdInstructionSetsInUse() -> str:
    """
    SimdInstructionSetsInUse() -> str :
        Get the set of SIMD instructions in use with Eigen.

        C++ signature :
            char const* SimdInstructionSetsInUse()
    """

def checkVersionAtLeast(major_version: int, minor_version: int, patch_version: int) -> bool:
    """
    checkVersionAtLeast( (int)major_version, (int)minor_version, (int)patch_version) -> bool :
        Checks if the current version of EigenPy is at least the version provided by the input arguments.

        C++ signature :
            bool checkVersionAtLeast(unsigned int,unsigned int,unsigned int)
    """

def fromEulerAngles(euler_angles: numpy.ndarray, a0: int, a1: int, a2: int) -> numpy.ndarray:
    """
    fromEulerAngles( (numpy.ndarray)euler_angles, (int)a0, (int)a1, (int)a2) -> numpy.ndarray :
        It returns the rotation matrix associated to the Euler angles using the convention defined by the triplet (a0,a1,a2).

        C++ signature :
            Eigen::Matrix<double, 3, 3, 0, 3, 3> fromEulerAngles(Eigen::Matrix<double, 3, 1, 0, 3, 1>,long,long,long)
    """

def is_approx(A: numpy.ndarray, B_: numpy.ndarray, prec: float = 1e-12) -> bool:
    """
    is_approx( (numpy.ndarray)A, (numpy.ndarray)B [, (float)prec=1e-12]) -> bool :
        Returns True if A is approximately equal to B, within the precision determined by prec.

        C++ signature :
            bool is_approx(Eigen::MatrixBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> >,Eigen::MatrixBase<Eigen::Matrix<double, -1, -1, 0, -1, -1> > [,double=1e-12])

        C++ signature :
            bool is_approx(Eigen::MatrixBase<Eigen::Matrix<std::complex<double>, -1, -1, 0, -1, -1> >,Eigen::MatrixBase<Eigen::Matrix<std::complex<double>, -1, -1, 0, -1, -1> > [,double=1e-12])
    """

def seed(seed_value: int) -> None:
    """
    seed( (int)seed_value) -> None :
        Initialize the pseudo-random number generator with the argument seed_value.

        C++ signature :
            void seed(unsigned int)
    """

@typing.overload
def sharedMemory() -> bool:
    """
    sharedMemory( (bool)value) -> None :
        Share the memory when converting from Eigen to Numpy.

        C++ signature :
            void sharedMemory(bool)

        C++ signature :
            bool sharedMemory()
    """
@typing.overload
def sharedMemory(value: bool) -> None:
    pass

def toEulerAngles(rotation_matrix: numpy.ndarray, a0: int, a1: int, a2: int) -> numpy.ndarray:
    """
    toEulerAngles( (numpy.ndarray)rotation_matrix, (int)a0, (int)a1, (int)a2) -> numpy.ndarray :
        It returns the Euler-angles of the rotation matrix mat using the convention defined by the triplet (a0,a1,a2).

        C++ signature :
            Eigen::Matrix<double, 3, 1, 0, 3, 1> toEulerAngles(Eigen::Matrix<double, 3, 3, 0, 3, 3>,long,long,long)
    """

__raw_version__ = '3.9.0'
__version__ = '3.9.0'
import Boost.Python
import numpy
_Shape = typing.Tuple[int, ...]

